#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import structuredefinition
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class StructureDefinitionTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("StructureDefinition", js["resourceType"])
        return structuredefinition.StructureDefinition(js)
    
    def testStructureDefinition1(self):
        inst = self.instantiate_from("structuredefinition-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a StructureDefinition instance")
        self.implStructureDefinition1(inst)
        
        js = inst.as_json()
        self.assertEqual("StructureDefinition", js["resourceType"])
        inst2 = structuredefinition.StructureDefinition(js)
        self.implStructureDefinition1(inst2)
    
    def implStructureDefinition1(self, inst):
        self.assertFalse(inst.abstract)
        self.assertEqual(force_bytes(inst.baseDefinition), force_bytes("http://hl7.org/fhir/StructureDefinition/DiagnosticReport"))
        self.assertEqual(force_bytes(inst.contact[0].name), force_bytes("Grahame Grieve"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].system), force_bytes("email"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].value), force_bytes("grahame@healthintersections.com.au"))
        self.assertEqual(force_bytes(inst.copyright), force_bytes("Creative Commons 0, per FHIR specification"))
        self.assertEqual(inst.date.date, FHIRDate("2012-05-12").date)
        self.assertEqual(inst.date.as_json(), "2012-05-12")
        self.assertEqual(force_bytes(inst.derivation), force_bytes("constraint"))
        self.assertEqual(force_bytes(inst.description), force_bytes("Describes how the lab report is used for a standard Lipid Profile - Cholesterol, Triglyceride and Cholesterol fractions. Uses LOINC codes"))
        self.assertTrue(inst.experimental)
        self.assertEqual(force_bytes(inst.fhirVersion), force_bytes("1.0.0"))
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("urn:ietf:rfc:3986"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("1.2.36.90146595217.4.2"))
        self.assertEqual(force_bytes(inst.jurisdiction[0].coding[0].code), force_bytes("AU"))
        self.assertEqual(force_bytes(inst.jurisdiction[0].coding[0].system), force_bytes("urn:iso:std:iso:3166"))
        self.assertEqual(force_bytes(inst.keyword[0].code), force_bytes("314079002"))
        self.assertEqual(force_bytes(inst.keyword[0].display), force_bytes("Hyperlipidemia screening test (procedure)"))
        self.assertEqual(force_bytes(inst.keyword[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.kind), force_bytes("resource"))
        self.assertEqual(force_bytes(inst.mapping[0].comment), force_bytes("Actual mappings haven't yet been filled out"))
        self.assertEqual(force_bytes(inst.mapping[0].identity), force_bytes("m1"))
        self.assertEqual(force_bytes(inst.mapping[0].name), force_bytes("RCPA Lipid Report recommendations"))
        self.assertEqual(force_bytes(inst.mapping[0].uri), force_bytes("https://www.rcpa.edu.au/getattachment/0961c6d1-ec80-4500-8dc0-de516500e05b/Lipid-and-lipoprotein-testing.aspx"))
        self.assertEqual(force_bytes(inst.name), force_bytes("LipidProfileExample"))
        self.assertEqual(force_bytes(inst.publisher), force_bytes("Health Intersections Pty Ltd"))
        self.assertEqual(force_bytes(inst.purpose), force_bytes("Provide an example to demonstrate how to use StructureDefinition"))
        self.assertEqual(force_bytes(inst.snapshot.element[0].base.max), force_bytes("1"))
        self.assertEqual(inst.snapshot.element[0].base.min, 1)
        self.assertEqual(force_bytes(inst.snapshot.element[0].base.path), force_bytes("DiagnosticReport"))
        self.assertEqual(force_bytes(inst.snapshot.element[0].definition), force_bytes("The findings and interpretation of a general lipd lab profile."))
        self.assertEqual(force_bytes(inst.snapshot.element[0].id), force_bytes("DiagnosticReport"))
        self.assertFalse(inst.snapshot.element[0].isModifier)
        self.assertEqual(force_bytes(inst.snapshot.element[0].max), force_bytes("1"))
        self.assertEqual(inst.snapshot.element[0].min, 1)
        self.assertEqual(force_bytes(inst.snapshot.element[0].path), force_bytes("DiagnosticReport"))
        self.assertEqual(force_bytes(inst.snapshot.element[0].short), force_bytes("Lipid Lab Report"))
        self.assertEqual(force_bytes(inst.snapshot.element[1].base.max), force_bytes("*"))
        self.assertEqual(inst.snapshot.element[1].base.min, 0)
        self.assertEqual(force_bytes(inst.snapshot.element[1].base.path), force_bytes("DiagnosticReport.extension"))
        self.assertEqual(force_bytes(inst.snapshot.element[1].id), force_bytes("DiagnosticReport.extension"))
        self.assertFalse(inst.snapshot.element[1].isModifier)
        self.assertEqual(force_bytes(inst.snapshot.element[1].max), force_bytes("*"))
        self.assertEqual(inst.snapshot.element[1].min, 0)
        self.assertEqual(force_bytes(inst.snapshot.element[1].path), force_bytes("DiagnosticReport.extension"))
        self.assertEqual(force_bytes(inst.snapshot.element[1].short), force_bytes("Additional Content defined by implementations"))
        self.assertEqual(force_bytes(inst.snapshot.element[1].slicing.discriminator[0].path), force_bytes("url"))
        self.assertEqual(force_bytes(inst.snapshot.element[1].slicing.discriminator[0].type), force_bytes("value"))
        self.assertFalse(inst.snapshot.element[1].slicing.ordered)
        self.assertEqual(force_bytes(inst.snapshot.element[1].slicing.rules), force_bytes("open"))
        self.assertEqual(force_bytes(inst.snapshot.element[1].type[0].code), force_bytes("Extension"))
        self.assertEqual(force_bytes(inst.snapshot.element[2].alias[0]), force_bytes("narrative"))
        self.assertEqual(force_bytes(inst.snapshot.element[2].alias[1]), force_bytes("html"))
        self.assertEqual(force_bytes(inst.snapshot.element[2].alias[2]), force_bytes("xhtml"))
        self.assertEqual(force_bytes(inst.snapshot.element[2].alias[3]), force_bytes("display"))
        self.assertEqual(force_bytes(inst.snapshot.element[2].base.max), force_bytes("1"))
        self.assertEqual(inst.snapshot.element[2].base.min, 0)
        self.assertEqual(force_bytes(inst.snapshot.element[2].base.path), force_bytes("DiagnosticReport.text"))
        self.assertEqual(force_bytes(inst.snapshot.element[2].comment), force_bytes("Contained resources do not have narrative. Resources that are not contained SHOULD have a narrative."))
        self.assertEqual(force_bytes(inst.snapshot.element[2].id), force_bytes("DiagnosticReport.text"))
        self.assertFalse(inst.snapshot.element[2].isModifier)
        self.assertEqual(force_bytes(inst.snapshot.element[2].max), force_bytes("1"))
        self.assertEqual(inst.snapshot.element[2].min, 0)
        self.assertEqual(force_bytes(inst.snapshot.element[2].path), force_bytes("DiagnosticReport.text"))
        self.assertEqual(force_bytes(inst.snapshot.element[2].short), force_bytes("Text summary of the resource, for human interpretation"))
        self.assertEqual(force_bytes(inst.snapshot.element[2].type[0].code), force_bytes("Narrative"))
        self.assertEqual(force_bytes(inst.snapshot.element[3].alias[0]), force_bytes("inline resources"))
        self.assertEqual(force_bytes(inst.snapshot.element[3].alias[1]), force_bytes("anonymous resources"))
        self.assertEqual(force_bytes(inst.snapshot.element[3].alias[2]), force_bytes("contained resources"))
        self.assertEqual(force_bytes(inst.snapshot.element[3].base.max), force_bytes("*"))
        self.assertEqual(inst.snapshot.element[3].base.min, 0)
        self.assertEqual(force_bytes(inst.snapshot.element[3].base.path), force_bytes("DiagnosticReport.contained"))
        self.assertEqual(force_bytes(inst.snapshot.element[3].comment), force_bytes("This should never be done when the content can be identified properly, as once identification is lost, it is extremely difficult (and context dependent) to restore it again."))
        self.assertEqual(force_bytes(inst.snapshot.element[3].id), force_bytes("DiagnosticReport.contained"))
        self.assertFalse(inst.snapshot.element[3].isModifier)
        self.assertEqual(force_bytes(inst.snapshot.element[3].max), force_bytes("*"))
        self.assertEqual(inst.snapshot.element[3].min, 0)
        self.assertEqual(force_bytes(inst.snapshot.element[3].path), force_bytes("DiagnosticReport.contained"))
        self.assertEqual(force_bytes(inst.snapshot.element[3].short), force_bytes("Contained, inline Resources"))
        self.assertEqual(force_bytes(inst.snapshot.element[3].type[0].code), force_bytes("Resource"))
        self.assertEqual(force_bytes(inst.snapshot.element[4].base.max), force_bytes("1"))
        self.assertEqual(inst.snapshot.element[4].base.min, 1)
        self.assertEqual(force_bytes(inst.snapshot.element[4].base.path), force_bytes("DiagnosticReport.status"))
        self.assertEqual(force_bytes(inst.snapshot.element[4].binding.strength), force_bytes("required"))
        self.assertEqual(force_bytes(inst.snapshot.element[4].comment), force_bytes("This is labeled as \"Is Modifier\" because applications need to take appropriate action if a report is withdrawn."))
        self.assertEqual(force_bytes(inst.snapshot.element[4].definition), force_bytes("The status of the diagnostic report as a whole."))
        self.assertEqual(force_bytes(inst.snapshot.element[4].id), force_bytes("DiagnosticReport.status"))
        self.assertFalse(inst.snapshot.element[4].isModifier)
        self.assertEqual(force_bytes(inst.snapshot.element[4].max), force_bytes("1"))
        self.assertEqual(inst.snapshot.element[4].min, 1)
        self.assertEqual(force_bytes(inst.snapshot.element[4].path), force_bytes("DiagnosticReport.status"))
        self.assertEqual(force_bytes(inst.snapshot.element[4].short), force_bytes("registered|interim|final|amended|cancelled|withdrawn"))
        self.assertEqual(force_bytes(inst.snapshot.element[4].type[0].code), force_bytes("code"))
        self.assertEqual(force_bytes(inst.snapshot.element[5].base.max), force_bytes("1"))
        self.assertEqual(inst.snapshot.element[5].base.min, 1)
        self.assertEqual(force_bytes(inst.snapshot.element[5].base.path), force_bytes("DiagnosticReport.issued"))
        self.assertEqual(force_bytes(inst.snapshot.element[5].comment), force_bytes("May be different from the update time of the resource itself, because that is the status of the record (potentially a secondary copy), not the actual release time of the report."))
        self.assertEqual(force_bytes(inst.snapshot.element[5].definition), force_bytes("The date and/or time that this version of the report was released from the source diagnostic service."))
        self.assertEqual(force_bytes(inst.snapshot.element[5].id), force_bytes("DiagnosticReport.issued"))
        self.assertFalse(inst.snapshot.element[5].isModifier)
        self.assertEqual(force_bytes(inst.snapshot.element[5].max), force_bytes("1"))
        self.assertEqual(inst.snapshot.element[5].min, 1)
        self.assertEqual(force_bytes(inst.snapshot.element[5].path), force_bytes("DiagnosticReport.issued"))
        self.assertEqual(force_bytes(inst.snapshot.element[5].short), force_bytes("Date this version was released"))
        self.assertEqual(force_bytes(inst.snapshot.element[5].type[0].code), force_bytes("dateTime"))
        self.assertEqual(force_bytes(inst.snapshot.element[6].base.max), force_bytes("1"))
        self.assertEqual(inst.snapshot.element[6].base.min, 1)
        self.assertEqual(force_bytes(inst.snapshot.element[6].base.path), force_bytes("DiagnosticReport.subject"))
        self.assertEqual(force_bytes(inst.snapshot.element[6].definition), force_bytes("The subject of the report. Usually, but not always, this is a patient. However diagnostic services also perform analyses on specimens collected from a variety of other sources."))
        self.assertEqual(force_bytes(inst.snapshot.element[6].id), force_bytes("DiagnosticReport.subject"))
        self.assertFalse(inst.snapshot.element[6].isModifier)
        self.assertEqual(force_bytes(inst.snapshot.element[6].max), force_bytes("1"))
        self.assertEqual(inst.snapshot.element[6].min, 1)
        self.assertEqual(force_bytes(inst.snapshot.element[6].path), force_bytes("DiagnosticReport.subject"))
        self.assertEqual(force_bytes(inst.snapshot.element[6].short), force_bytes("The subject of the report"))
        self.assertEqual(force_bytes(inst.snapshot.element[6].type[0].aggregation[0]), force_bytes("bundled"))
        self.assertEqual(force_bytes(inst.snapshot.element[6].type[0].code), force_bytes("Reference"))
        self.assertEqual(force_bytes(inst.snapshot.element[6].type[0].targetProfile), force_bytes("http://hl7.org/fhir/StructureDefinition/Patient"))
        self.assertEqual(force_bytes(inst.snapshot.element[6].type[0].versioning), force_bytes("either"))
        self.assertEqual(force_bytes(inst.snapshot.element[6].type[1].aggregation[0]), force_bytes("bundled"))
        self.assertEqual(force_bytes(inst.snapshot.element[6].type[1].code), force_bytes("Reference"))
        self.assertEqual(force_bytes(inst.snapshot.element[6].type[1].targetProfile), force_bytes("http://hl7.org/fhir/StructureDefinition/Group"))
        self.assertEqual(force_bytes(inst.snapshot.element[6].type[2].aggregation[0]), force_bytes("bundled"))
        self.assertEqual(force_bytes(inst.snapshot.element[6].type[2].code), force_bytes("Reference"))
        self.assertEqual(force_bytes(inst.snapshot.element[6].type[2].targetProfile), force_bytes("http://hl7.org/fhir/StructureDefinition/Device"))
        self.assertEqual(force_bytes(inst.snapshot.element[7].base.max), force_bytes("1"))
        self.assertEqual(inst.snapshot.element[7].base.min, 1)
        self.assertEqual(force_bytes(inst.snapshot.element[7].base.path), force_bytes("DiagnosticReport.performer"))
        self.assertEqual(force_bytes(inst.snapshot.element[7].comment), force_bytes("This is not necessarily the source of the atomic data items - it's the entity that takes responsibility for the clinical report."))
        self.assertEqual(force_bytes(inst.snapshot.element[7].definition), force_bytes("The diagnostic service that is responsible for issuing the report."))
        self.assertEqual(force_bytes(inst.snapshot.element[7].id), force_bytes("DiagnosticReport.performer"))
        self.assertFalse(inst.snapshot.element[7].isModifier)
        self.assertEqual(force_bytes(inst.snapshot.element[7].max), force_bytes("1"))
        self.assertEqual(inst.snapshot.element[7].min, 1)
        self.assertEqual(force_bytes(inst.snapshot.element[7].path), force_bytes("DiagnosticReport.performer"))
        self.assertEqual(force_bytes(inst.snapshot.element[7].short), force_bytes("Responsible Diagnostic Service"))
        self.assertEqual(force_bytes(inst.snapshot.element[7].type[0].code), force_bytes("Reference"))
        self.assertEqual(force_bytes(inst.snapshot.element[7].type[0].targetProfile), force_bytes("http://hl7.org/fhir/StructureDefinition/Organization"))
        self.assertEqual(force_bytes(inst.snapshot.element[8].base.max), force_bytes("*"))
        self.assertEqual(inst.snapshot.element[8].base.min, 0)
        self.assertEqual(force_bytes(inst.snapshot.element[8].base.path), force_bytes("DiagnosticReport.identifier"))
        self.assertEqual(force_bytes(inst.snapshot.element[8].definition), force_bytes("The local ID assigned to the report by the order filler, usually by the Information System of the diagnostic service provider."))
        self.assertEqual(force_bytes(inst.snapshot.element[8].id), force_bytes("DiagnosticReport.identifier"))
        self.assertFalse(inst.snapshot.element[8].isModifier)
        self.assertEqual(force_bytes(inst.snapshot.element[8].max), force_bytes("1"))
        self.assertEqual(inst.snapshot.element[8].min, 0)
        self.assertEqual(force_bytes(inst.snapshot.element[8].path), force_bytes("DiagnosticReport.identifier"))
        self.assertEqual(force_bytes(inst.snapshot.element[8].short), force_bytes("Id for external references to this report"))
        self.assertEqual(force_bytes(inst.snapshot.element[8].type[0].code), force_bytes("Identifier"))
        self.assertEqual(force_bytes(inst.snapshot.element[9].base.max), force_bytes("*"))
        self.assertEqual(inst.snapshot.element[9].base.min, 0)
        self.assertEqual(force_bytes(inst.snapshot.element[9].base.path), force_bytes("DiagnosticReport.request"))
        self.assertEqual(force_bytes(inst.snapshot.element[9].definition), force_bytes("Details concerning a single pathology test requested."))
        self.assertEqual(force_bytes(inst.snapshot.element[9].id), force_bytes("DiagnosticReport.request"))
        self.assertFalse(inst.snapshot.element[9].isModifier)
        self.assertEqual(force_bytes(inst.snapshot.element[9].max), force_bytes("*"))
        self.assertEqual(inst.snapshot.element[9].min, 0)
        self.assertEqual(force_bytes(inst.snapshot.element[9].path), force_bytes("DiagnosticReport.request"))
        self.assertEqual(force_bytes(inst.snapshot.element[9].short), force_bytes("What was requested"))
        self.assertEqual(force_bytes(inst.snapshot.element[9].type[0].aggregation[0]), force_bytes("referenced"))
        self.assertEqual(force_bytes(inst.snapshot.element[9].type[0].code), force_bytes("Reference"))
        self.assertEqual(force_bytes(inst.snapshot.element[9].type[0].targetProfile), force_bytes("http://hl7.org/fhir/StructureDefinition/ProcedureRequest"))
        self.assertEqual(force_bytes(inst.snapshot.element[9].type[0].versioning), force_bytes("specific"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.title), force_bytes("Example Lipid Profile"))
        self.assertEqual(force_bytes(inst.type), force_bytes("DiagnosticReport"))
        self.assertEqual(force_bytes(inst.url), force_bytes("http://hl7.org/fhir/StructureDefinition/example"))
        self.assertEqual(force_bytes(inst.useContext[0].code.code), force_bytes("focus"))
        self.assertEqual(force_bytes(inst.useContext[0].code.display), force_bytes("Clinical Focus"))
        self.assertEqual(force_bytes(inst.useContext[0].code.system), force_bytes("http://hl7.org/fhir/usage-context-type"))
        self.assertEqual(force_bytes(inst.useContext[0].valueCodeableConcept.coding[0].code), force_bytes("314079002"))
        self.assertEqual(force_bytes(inst.useContext[0].valueCodeableConcept.coding[0].display), force_bytes("Hyperlipidemia screening test (procedure)"))
        self.assertEqual(force_bytes(inst.useContext[0].valueCodeableConcept.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.version), force_bytes("2"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import coverage
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class CoverageTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Coverage", js["resourceType"])
        return coverage.Coverage(js)
    
    def testCoverage1(self):
        inst = self.instantiate_from("coverage-example-selfpay.json")
        self.assertIsNotNone(inst, "Must have instantiated a Coverage instance")
        self.implCoverage1(inst)
        
        js = inst.as_json()
        self.assertEqual("Coverage", js["resourceType"])
        inst2 = coverage.Coverage(js)
        self.implCoverage1(inst2)
    
    def implCoverage1(self, inst):
        self.assertEqual(force_bytes(inst.id), force_bytes("SP1234"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://hospitalx.com/selfpayagreement"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("SP12345678"))
        self.assertEqual(inst.period.end.date, FHIRDate("2012-03-17").date)
        self.assertEqual(inst.period.end.as_json(), "2012-03-17")
        self.assertEqual(force_bytes(inst.relationship.coding[0].code), force_bytes("self"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of a Self Pay Agreement.</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("pay"))
        self.assertEqual(force_bytes(inst.type.coding[0].display), force_bytes("PAY"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("http://hl7.org/fhir/coverage-selfpay"))
    
    def testCoverage2(self):
        inst = self.instantiate_from("coverage-example-2.json")
        self.assertIsNotNone(inst, "Must have instantiated a Coverage instance")
        self.implCoverage2(inst)
        
        js = inst.as_json()
        self.assertEqual("Coverage", js["resourceType"])
        inst2 = coverage.Coverage(js)
        self.implCoverage2(inst2)
    
    def implCoverage2(self, inst):
        self.assertEqual(force_bytes(inst.dependent), force_bytes("1"))
        self.assertEqual(force_bytes(inst.grouping.group), force_bytes("WESTAIR"))
        self.assertEqual(force_bytes(inst.grouping.groupDisplay), force_bytes("Western Airlines"))
        self.assertEqual(force_bytes(inst.grouping.plan), force_bytes("WESTAIR"))
        self.assertEqual(force_bytes(inst.grouping.planDisplay), force_bytes("Western Airlines"))
        self.assertEqual(force_bytes(inst.grouping.subPlan), force_bytes("D15C9"))
        self.assertEqual(force_bytes(inst.grouping.subPlanDisplay), force_bytes("Platinum"))
        self.assertEqual(force_bytes(inst.id), force_bytes("7546D"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://xyz.com/codes/identifier"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("AB98761"))
        self.assertEqual(force_bytes(inst.network), force_bytes("5"))
        self.assertEqual(inst.order, 2)
        self.assertEqual(inst.period.end.date, FHIRDate("2012-03-17").date)
        self.assertEqual(inst.period.end.as_json(), "2012-03-17")
        self.assertEqual(inst.period.start.date, FHIRDate("2011-03-17").date)
        self.assertEqual(inst.period.start.as_json(), "2011-03-17")
        self.assertEqual(force_bytes(inst.relationship.coding[0].code), force_bytes("self"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.subscriberId), force_bytes("AB9876"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the coverage</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("EHCPOL"))
        self.assertEqual(force_bytes(inst.type.coding[0].display), force_bytes("extended healthcare"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ActCode"))
    
    def testCoverage3(self):
        inst = self.instantiate_from("coverage-example-ehic.json")
        self.assertIsNotNone(inst, "Must have instantiated a Coverage instance")
        self.implCoverage3(inst)
        
        js = inst.as_json()
        self.assertEqual("Coverage", js["resourceType"])
        inst2 = coverage.Coverage(js)
        self.implCoverage3(inst2)
    
    def implCoverage3(self, inst):
        self.assertEqual(force_bytes(inst.id), force_bytes("7547E"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://ehic.com/insurer/123456789/member"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("A123456780"))
        self.assertEqual(inst.period.end.date, FHIRDate("2012-03-17").date)
        self.assertEqual(inst.period.end.as_json(), "2012-03-17")
        self.assertEqual(force_bytes(inst.relationship.coding[0].code), force_bytes("self"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the European Health Insurance Card</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("EHCPOL"))
        self.assertEqual(force_bytes(inst.type.coding[0].display), force_bytes("extended healthcare"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ActCode"))
    
    def testCoverage4(self):
        inst = self.instantiate_from("coverage-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Coverage instance")
        self.implCoverage4(inst)
        
        js = inst.as_json()
        self.assertEqual("Coverage", js["resourceType"])
        inst2 = coverage.Coverage(js)
        self.implCoverage4(inst2)
    
    def implCoverage4(self, inst):
        self.assertEqual(force_bytes(inst.dependent), force_bytes("0"))
        self.assertEqual(force_bytes(inst.grouping.classDisplay), force_bytes("Silver: Family Plan spouse only"))
        self.assertEqual(force_bytes(inst.grouping.class_fhir), force_bytes("SILVER"))
        self.assertEqual(force_bytes(inst.grouping.group), force_bytes("CBI35"))
        self.assertEqual(force_bytes(inst.grouping.groupDisplay), force_bytes("Corporate Baker's Inc. Local #35"))
        self.assertEqual(force_bytes(inst.grouping.plan), force_bytes("B37FC"))
        self.assertEqual(force_bytes(inst.grouping.planDisplay), force_bytes("Full Coverage: Medical, Dental, Pharmacy, Vision, EHC"))
        self.assertEqual(force_bytes(inst.grouping.subClass), force_bytes("Tier2"))
        self.assertEqual(force_bytes(inst.grouping.subClassDisplay), force_bytes("Low deductable, max $20 copay"))
        self.assertEqual(force_bytes(inst.grouping.subGroup), force_bytes("123"))
        self.assertEqual(force_bytes(inst.grouping.subGroupDisplay), force_bytes("Trainee Part-time Benefits"))
        self.assertEqual(force_bytes(inst.grouping.subPlan), force_bytes("P7"))
        self.assertEqual(force_bytes(inst.grouping.subPlanDisplay), force_bytes("Includes afterlife benefits"))
        self.assertEqual(force_bytes(inst.id), force_bytes("9876B1"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://benefitsinc.com/certificate"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("12345"))
        self.assertEqual(inst.period.end.date, FHIRDate("2012-05-23").date)
        self.assertEqual(inst.period.end.as_json(), "2012-05-23")
        self.assertEqual(inst.period.start.date, FHIRDate("2011-05-23").date)
        self.assertEqual(inst.period.start.as_json(), "2011-05-23")
        self.assertEqual(force_bytes(inst.relationship.coding[0].code), force_bytes("self"))
        self.assertEqual(force_bytes(inst.sequence), force_bytes("9"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">A human-readable rendering of the coverage</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("EHCPOL"))
        self.assertEqual(force_bytes(inst.type.coding[0].display), force_bytes("extended healthcare"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("http://hl7.org/fhir/v3/ActCode"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 (http://hl7.org/fhir/StructureDefinition/EligibilityResponse) on 2019-01-12.
#  2019, SMART Health IT.


from . import domainresource

class EligibilityResponse(domainresource.DomainResource):
    """ EligibilityResponse resource.
    
    This resource provides eligibility and plan details from the processing of
    an Eligibility resource.
    """
    
    resource_type = "EligibilityResponse"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.created = None
        """ Creation date.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.disposition = None
        """ Disposition Message.
        Type `str`. """
        
        self.error = None
        """ Processing errors.
        List of `EligibilityResponseError` items (represented as `dict` in JSON). """
        
        self.form = None
        """ Printed Form Identifier.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.identifier = None
        """ Business Identifier.
        List of `Identifier` items (represented as `dict` in JSON). """
        
        self.inforce = None
        """ Coverage inforce indicator.
        Type `bool`. """
        
        self.insurance = None
        """ Details by insurance coverage.
        List of `EligibilityResponseInsurance` items (represented as `dict` in JSON). """
        
        self.insurer = None
        """ Insurer issuing the coverage.
        Type `FHIRReference` referencing `Organization` (represented as `dict` in JSON). """
        
        self.outcome = None
        """ complete | error | partial.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.request = None
        """ Eligibility reference.
        Type `FHIRReference` referencing `EligibilityRequest` (represented as `dict` in JSON). """
        
        self.requestOrganization = None
        """ Responsible organization.
        Type `FHIRReference` referencing `Organization` (represented as `dict` in JSON). """
        
        self.requestProvider = None
        """ Responsible practitioner.
        Type `FHIRReference` referencing `Practitioner` (represented as `dict` in JSON). """
        
        self.status = None
        """ active | cancelled | draft | entered-in-error.
        Type `str`. """
        
        super(EligibilityResponse, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(EligibilityResponse, self).elementProperties()
        js.extend([
            ("created", "created", fhirdate.FHIRDate, False, None, False),
            ("disposition", "disposition", str, False, None, False),
            ("error", "error", EligibilityResponseError, True, None, False),
            ("form", "form", codeableconcept.CodeableConcept, False, None, False),
            ("identifier", "identifier", identifier.Identifier, True, None, False),
            ("inforce", "inforce", bool, False, None, False),
            ("insurance", "insurance", EligibilityResponseInsurance, True, None, False),
            ("insurer", "insurer", fhirreference.FHIRReference, False, None, False),
            ("outcome", "outcome", codeableconcept.CodeableConcept, False, None, False),
            ("request", "request", fhirreference.FHIRReference, False, None, False),
            ("requestOrganization", "requestOrganization", fhirreference.FHIRReference, False, None, False),
            ("requestProvider", "requestProvider", fhirreference.FHIRReference, False, None, False),
            ("status", "status", str, False, None, False),
        ])
        return js


from . import backboneelement

class EligibilityResponseError(backboneelement.BackboneElement):
    """ Processing errors.
    
    Mutually exclusive with Services Provided (Item).
    """
    
    resource_type = "EligibilityResponseError"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.code = None
        """ Error code detailing processing issues.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        super(EligibilityResponseError, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(EligibilityResponseError, self).elementProperties()
        js.extend([
            ("code", "code", codeableconcept.CodeableConcept, False, None, True),
        ])
        return js


class EligibilityResponseInsurance(backboneelement.BackboneElement):
    """ Details by insurance coverage.
    
    The insurer may provide both the details for the requested coverage as well
    as details for additional coverages known to the insurer.
    """
    
    resource_type = "EligibilityResponseInsurance"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.benefitBalance = None
        """ Benefits by Category.
        List of `EligibilityResponseInsuranceBenefitBalance` items (represented as `dict` in JSON). """
        
        self.contract = None
        """ Contract details.
        Type `FHIRReference` referencing `Contract` (represented as `dict` in JSON). """
        
        self.coverage = None
        """ Updated Coverage details.
        Type `FHIRReference` referencing `Coverage` (represented as `dict` in JSON). """
        
        super(EligibilityResponseInsurance, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(EligibilityResponseInsurance, self).elementProperties()
        js.extend([
            ("benefitBalance", "benefitBalance", EligibilityResponseInsuranceBenefitBalance, True, None, False),
            ("contract", "contract", fhirreference.FHIRReference, False, None, False),
            ("coverage", "coverage", fhirreference.FHIRReference, False, None, False),
        ])
        return js


class EligibilityResponseInsuranceBenefitBalance(backboneelement.BackboneElement):
    """ Benefits by Category.
    
    Benefits and optionally current balances by Category.
    """
    
    resource_type = "EligibilityResponseInsuranceBenefitBalance"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.category = None
        """ Type of services covered.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.description = None
        """ Description of the benefit or services covered.
        Type `str`. """
        
        self.excluded = None
        """ Excluded from the plan.
        Type `bool`. """
        
        self.financial = None
        """ Benefit Summary.
        List of `EligibilityResponseInsuranceBenefitBalanceFinancial` items (represented as `dict` in JSON). """
        
        self.name = None
        """ Short name for the benefit.
        Type `str`. """
        
        self.network = None
        """ In or out of network.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.subCategory = None
        """ Detailed services covered within the type.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.term = None
        """ Annual or lifetime.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.unit = None
        """ Individual or family.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        super(EligibilityResponseInsuranceBenefitBalance, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(EligibilityResponseInsuranceBenefitBalance, self).elementProperties()
        js.extend([
            ("category", "category", codeableconcept.CodeableConcept, False, None, True),
            ("description", "description", str, False, None, False),
            ("excluded", "excluded", bool, False, None, False),
            ("financial", "financial", EligibilityResponseInsuranceBenefitBalanceFinancial, True, None, False),
            ("name", "name", str, False, None, False),
            ("network", "network", codeableconcept.CodeableConcept, False, None, False),
            ("subCategory", "subCategory", codeableconcept.CodeableConcept, False, None, False),
            ("term", "term", codeableconcept.CodeableConcept, False, None, False),
            ("unit", "unit", codeableconcept.CodeableConcept, False, None, False),
        ])
        return js


class EligibilityResponseInsuranceBenefitBalanceFinancial(backboneelement.BackboneElement):
    """ Benefit Summary.
    
    Benefits Used to date.
    """
    
    resource_type = "EligibilityResponseInsuranceBenefitBalanceFinancial"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.allowedMoney = None
        """ Benefits allowed.
        Type `Money` (represented as `dict` in JSON). """
        
        self.allowedString = None
        """ Benefits allowed.
        Type `str`. """
        
        self.allowedUnsignedInt = None
        """ Benefits allowed.
        Type `int`. """
        
        self.type = None
        """ Deductable, visits, benefit amount.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.usedMoney = None
        """ Benefits used.
        Type `Money` (represented as `dict` in JSON). """
        
        self.usedUnsignedInt = None
        """ Benefits used.
        Type `int`. """
        
        super(EligibilityResponseInsuranceBenefitBalanceFinancial, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(EligibilityResponseInsuranceBenefitBalanceFinancial, self).elementProperties()
        js.extend([
            ("allowedMoney", "allowedMoney", money.Money, False, "allowed", False),
            ("allowedString", "allowedString", str, False, "allowed", False),
            ("allowedUnsignedInt", "allowedUnsignedInt", int, False, "allowed", False),
            ("type", "type", codeableconcept.CodeableConcept, False, None, True),
            ("usedMoney", "usedMoney", money.Money, False, "used", False),
            ("usedUnsignedInt", "usedUnsignedInt", int, False, "used", False),
        ])
        return js


import sys
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']
try:
    from . import money
except ImportError:
    money = sys.modules[__package__ + '.money']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 (http://hl7.org/fhir/StructureDefinition/Goal) on 2019-01-12.
#  2019, SMART Health IT.


from . import domainresource

class Goal(domainresource.DomainResource):
    """ Describes the intended objective(s) for a patient, group or organization.
    
    Describes the intended objective(s) for a patient, group or organization
    care, for example, weight loss, restoring an activity of daily living,
    obtaining herd immunity via immunization, meeting a process improvement
    objective, etc.
    """
    
    resource_type = "Goal"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.addresses = None
        """ Issues addressed by this goal.
        List of `FHIRReference` items referencing `Condition, Observation, MedicationStatement, NutritionOrder, ProcedureRequest, RiskAssessment` (represented as `dict` in JSON). """
        
        self.category = None
        """ E.g. Treatment, dietary, behavioral, etc..
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.description = None
        """ Code or text describing goal.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.expressedBy = None
        """ Who's responsible for creating Goal?.
        Type `FHIRReference` referencing `Patient, Practitioner, RelatedPerson` (represented as `dict` in JSON). """
        
        self.identifier = None
        """ External Ids for this goal.
        List of `Identifier` items (represented as `dict` in JSON). """
        
        self.note = None
        """ Comments about the goal.
        List of `Annotation` items (represented as `dict` in JSON). """
        
        self.outcomeCode = None
        """ What result was achieved regarding the goal?.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.outcomeReference = None
        """ Observation that resulted from goal.
        List of `FHIRReference` items referencing `Observation` (represented as `dict` in JSON). """
        
        self.priority = None
        """ high-priority | medium-priority | low-priority.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.startCodeableConcept = None
        """ When goal pursuit begins.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.startDate = None
        """ When goal pursuit begins.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.status = None
        """ proposed | accepted | planned | in-progress | on-target | ahead-of-
        target | behind-target | sustaining | achieved | on-hold |
        cancelled | entered-in-error | rejected.
        Type `str`. """
        
        self.statusDate = None
        """ When goal status took effect.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.statusReason = None
        """ Reason for current status.
        Type `str`. """
        
        self.subject = None
        """ Who this goal is intended for.
        Type `FHIRReference` referencing `Patient, Group, Organization` (represented as `dict` in JSON). """
        
        self.target = None
        """ Target outcome for the goal.
        Type `GoalTarget` (represented as `dict` in JSON). """
        
        super(Goal, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(Goal, self).elementProperties()
        js.extend([
            ("addresses", "addresses", fhirreference.FHIRReference, True, None, False),
            ("category", "category", codeableconcept.CodeableConcept, True, None, False),
            ("description", "description", codeableconcept.CodeableConcept, False, None, True),
            ("expressedBy", "expressedBy", fhirreference.FHIRReference, False, None, False),
            ("identifier", "identifier", identifier.Identifier, True, None, False),
            ("note", "note", annotation.Annotation, True, None, False),
            ("outcomeCode", "outcomeCode", codeableconcept.CodeableConcept, True, None, False),
            ("outcomeReference", "outcomeReference", fhirreference.FHIRReference, True, None, False),
            ("priority", "priority", codeableconcept.CodeableConcept, False, None, False),
            ("startCodeableConcept", "startCodeableConcept", codeableconcept.CodeableConcept, False, "start", False),
            ("startDate", "startDate", fhirdate.FHIRDate, False, "start", False),
            ("status", "status", str, False, None, True),
            ("statusDate", "statusDate", fhirdate.FHIRDate, False, None, False),
            ("statusReason", "statusReason", str, False, None, False),
            ("subject", "subject", fhirreference.FHIRReference, False, None, False),
            ("target", "target", GoalTarget, False, None, False),
        ])
        return js


from . import backboneelement

class GoalTarget(backboneelement.BackboneElement):
    """ Target outcome for the goal.
    
    Indicates what should be done by when.
    """
    
    resource_type = "GoalTarget"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.detailCodeableConcept = None
        """ The target value to be achieved.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.detailQuantity = None
        """ The target value to be achieved.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.detailRange = None
        """ The target value to be achieved.
        Type `Range` (represented as `dict` in JSON). """
        
        self.dueDate = None
        """ Reach goal on or before.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.dueDuration = None
        """ Reach goal on or before.
        Type `Duration` (represented as `dict` in JSON). """
        
        self.measure = None
        """ The parameter whose value is being tracked.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        super(GoalTarget, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(GoalTarget, self).elementProperties()
        js.extend([
            ("detailCodeableConcept", "detailCodeableConcept", codeableconcept.CodeableConcept, False, "detail", False),
            ("detailQuantity", "detailQuantity", quantity.Quantity, False, "detail", False),
            ("detailRange", "detailRange", range.Range, False, "detail", False),
            ("dueDate", "dueDate", fhirdate.FHIRDate, False, "due", False),
            ("dueDuration", "dueDuration", duration.Duration, False, "due", False),
            ("measure", "measure", codeableconcept.CodeableConcept, False, None, False),
        ])
        return js


import sys
try:
    from . import annotation
except ImportError:
    annotation = sys.modules[__package__ + '.annotation']
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import duration
except ImportError:
    duration = sys.modules[__package__ + '.duration']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']
try:
    from . import quantity
except ImportError:
    quantity = sys.modules[__package__ + '.quantity']
try:
    from . import range
except ImportError:
    range = sys.modules[__package__ + '.range']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import devicecomponent
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class DeviceComponentTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("DeviceComponent", js["resourceType"])
        return devicecomponent.DeviceComponent(js)
    
    def testDeviceComponent1(self):
        inst = self.instantiate_from("devicecomponent-example-prodspec.json")
        self.assertIsNotNone(inst, "Must have instantiated a DeviceComponent instance")
        self.implDeviceComponent1(inst)
        
        js = inst.as_json()
        self.assertEqual("DeviceComponent", js["resourceType"])
        inst2 = devicecomponent.DeviceComponent(js)
        self.implDeviceComponent1(inst2)
    
    def implDeviceComponent1(self, inst):
        self.assertEqual(force_bytes(inst.id), force_bytes("example-prodspec"))
        self.assertEqual(force_bytes(inst.identifier.value), force_bytes("789123"))
        self.assertEqual(force_bytes(inst.languageCode.coding[0].code), force_bytes("en-US"))
        self.assertEqual(force_bytes(inst.languageCode.coding[0].system), force_bytes("http://tools.ietf.org/html/bcp47"))
        self.assertEqual(inst.lastSystemChange.date, FHIRDate("2014-10-07T14:45:00Z").date)
        self.assertEqual(inst.lastSystemChange.as_json(), "2014-10-07T14:45:00Z")
        self.assertEqual(force_bytes(inst.operationalStatus[0].coding[0].code), force_bytes("off"))
        self.assertEqual(force_bytes(inst.operationalStatus[0].coding[0].display), force_bytes("Off"))
        self.assertEqual(force_bytes(inst.productionSpecification[0].productionSpec), force_bytes("xa-12324-b"))
        self.assertEqual(force_bytes(inst.productionSpecification[0].specType.coding[0].code), force_bytes("serial-number"))
        self.assertEqual(force_bytes(inst.productionSpecification[0].specType.coding[0].display), force_bytes("Serial number"))
        self.assertEqual(force_bytes(inst.productionSpecification[1].productionSpec), force_bytes("1.1"))
        self.assertEqual(force_bytes(inst.productionSpecification[1].specType.coding[0].code), force_bytes("hardware-revision"))
        self.assertEqual(force_bytes(inst.productionSpecification[1].specType.coding[0].display), force_bytes("Hardware Revision"))
        self.assertEqual(force_bytes(inst.productionSpecification[2].productionSpec), force_bytes("1.12"))
        self.assertEqual(force_bytes(inst.productionSpecification[2].specType.coding[0].code), force_bytes("software-revision"))
        self.assertEqual(force_bytes(inst.productionSpecification[2].specType.coding[0].display), force_bytes("Software Revision"))
        self.assertEqual(force_bytes(inst.productionSpecification[3].productionSpec), force_bytes("1.0.23"))
        self.assertEqual(force_bytes(inst.productionSpecification[3].specType.coding[0].code), force_bytes("firmware-revision"))
        self.assertEqual(force_bytes(inst.productionSpecification[3].specType.coding[0].display), force_bytes("Firmware Revision"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("2000"))
        self.assertEqual(force_bytes(inst.type.coding[0].display), force_bytes("MDC_DEV_ANALY_SAT_O2_MDS"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("urn:iso:std:iso:11073:10101"))
    
    def testDeviceComponent2(self):
        inst = self.instantiate_from("devicecomponent-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a DeviceComponent instance")
        self.implDeviceComponent2(inst)
        
        js = inst.as_json()
        self.assertEqual("DeviceComponent", js["resourceType"])
        inst2 = devicecomponent.DeviceComponent(js)
        self.implDeviceComponent2(inst2)
    
    def implDeviceComponent2(self, inst):
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.identifier.value), force_bytes("0"))
        self.assertEqual(force_bytes(inst.languageCode.coding[0].code), force_bytes("en-US"))
        self.assertEqual(force_bytes(inst.languageCode.coding[0].system), force_bytes("http://tools.ietf.org/html/bcp47"))
        self.assertEqual(inst.lastSystemChange.date, FHIRDate("2014-10-07T14:45:00Z").date)
        self.assertEqual(inst.lastSystemChange.as_json(), "2014-10-07T14:45:00Z")
        self.assertEqual(force_bytes(inst.measurementPrinciple), force_bytes("optical"))
        self.assertEqual(force_bytes(inst.operationalStatus[0].coding[0].code), force_bytes("off"))
        self.assertEqual(force_bytes(inst.operationalStatus[0].coding[0].display), force_bytes("Off"))
        self.assertEqual(force_bytes(inst.operationalStatus[0].coding[0].system), force_bytes("urn:iso:std:iso:11073:10101"))
        self.assertEqual(force_bytes(inst.parameterGroup.coding[0].code), force_bytes("miscellaneous"))
        self.assertEqual(force_bytes(inst.parameterGroup.coding[0].display), force_bytes("Miscellaneous Parameter Group"))
        self.assertEqual(force_bytes(inst.parameterGroup.coding[0].system), force_bytes("urn:iso:std:iso:11073:10101"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type.coding[0].code), force_bytes("2000"))
        self.assertEqual(force_bytes(inst.type.coding[0].display), force_bytes("MDC_DEV_ANALY_SAT_O2_MDS"))
        self.assertEqual(force_bytes(inst.type.coding[0].system), force_bytes("urn:iso:std:iso:11073:10101"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import valueset
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class ValueSetTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("ValueSet", js["resourceType"])
        return valueset.ValueSet(js)
    
    def testValueSet1(self):
        inst = self.instantiate_from("valueset-example-expansion.json")
        self.assertIsNotNone(inst, "Must have instantiated a ValueSet instance")
        self.implValueSet1(inst)
        
        js = inst.as_json()
        self.assertEqual("ValueSet", js["resourceType"])
        inst2 = valueset.ValueSet(js)
        self.implValueSet1(inst2)
    
    def implValueSet1(self, inst):
        self.assertEqual(force_bytes(inst.compose.include[0].filter[0].op), force_bytes("="))
        self.assertEqual(force_bytes(inst.compose.include[0].filter[0].property), force_bytes("parent"))
        self.assertEqual(force_bytes(inst.compose.include[0].filter[0].value), force_bytes("LP43571-6"))
        self.assertEqual(force_bytes(inst.compose.include[0].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].system), force_bytes("url"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].value), force_bytes("http://hl7.org/fhir"))
        self.assertEqual(force_bytes(inst.copyright), force_bytes("This content from LOINC® is copyright © 1995 Regenstrief Institute, Inc. and the LOINC Committee, and available at no cost under the license at http://loinc.org/terms-of-use."))
        self.assertEqual(inst.date.date, FHIRDate("2015-06-22").date)
        self.assertEqual(inst.date.as_json(), "2015-06-22")
        self.assertEqual(force_bytes(inst.description), force_bytes("This is an example value set that includes all the LOINC codes for serum/plasma cholesterol from v2.36."))
        self.assertEqual(force_bytes(inst.expansion.contains[0].code), force_bytes("14647-2"))
        self.assertEqual(force_bytes(inst.expansion.contains[0].display), force_bytes("Cholesterol [Moles/volume] in Serum or Plasma"))
        self.assertEqual(force_bytes(inst.expansion.contains[0].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.expansion.contains[0].version), force_bytes("2.50"))
        self.assertTrue(inst.expansion.contains[1].abstract)
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[0].code), force_bytes("2093-3"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[0].display), force_bytes("Cholesterol [Mass/volume] in Serum or Plasma"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[0].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[0].version), force_bytes("2.50"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[1].code), force_bytes("48620-9"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[1].display), force_bytes("Cholesterol [Mass/volume] in Serum or Plasma ultracentrifugate"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[1].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[1].version), force_bytes("2.50"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[2].code), force_bytes("9342-7"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[2].display), force_bytes("Cholesterol [Percentile]"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[2].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[2].version), force_bytes("2.50"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].display), force_bytes("Cholesterol codes"))
        self.assertTrue(inst.expansion.contains[2].abstract)
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[0].code), force_bytes("2096-6"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[0].display), force_bytes("Cholesterol/Triglyceride [Mass Ratio] in Serum or Plasma"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[0].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[0].version), force_bytes("2.50"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[1].code), force_bytes("35200-5"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[1].display), force_bytes("Cholesterol/Triglyceride [Mass Ratio] in Serum or Plasma"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[1].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[1].version), force_bytes("2.50"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[2].code), force_bytes("48089-7"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[2].display), force_bytes("Cholesterol/Apolipoprotein B [Molar ratio] in Serum or Plasma"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[2].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[2].version), force_bytes("2.50"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[3].code), force_bytes("55838-7"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[3].display), force_bytes("Cholesterol/Phospholipid [Molar ratio] in Serum or Plasma"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[3].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].contains[3].version), force_bytes("2.50"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].display), force_bytes("Cholesterol Ratios"))
        self.assertEqual(force_bytes(inst.expansion.extension[0].url), force_bytes("http://hl7.org/fhir/StructureDefinition/valueset-expansionSource"))
        self.assertEqual(force_bytes(inst.expansion.extension[0].valueUri), force_bytes("http://hl7.org/fhir/ValueSet/example-extensional"))
        self.assertEqual(force_bytes(inst.expansion.identifier), force_bytes("urn:uuid:42316ff8-2714-4680-9980-f37a6d1a71bc"))
        self.assertEqual(inst.expansion.offset, 0)
        self.assertEqual(force_bytes(inst.expansion.parameter[0].name), force_bytes("version"))
        self.assertEqual(force_bytes(inst.expansion.parameter[0].valueString), force_bytes("2.50"))
        self.assertEqual(inst.expansion.timestamp.date, FHIRDate("2015-06-22T13:56:07Z").date)
        self.assertEqual(inst.expansion.timestamp.as_json(), "2015-06-22T13:56:07Z")
        self.assertEqual(inst.expansion.total, 8)
        self.assertTrue(inst.experimental)
        self.assertEqual(force_bytes(inst.id), force_bytes("example-expansion"))
        self.assertEqual(force_bytes(inst.meta.profile[0]), force_bytes("http://hl7.org/fhir/StructureDefinition/shareablevalueset"))
        self.assertEqual(force_bytes(inst.name), force_bytes("LOINC Codes for Cholesterol in Serum/Plasma"))
        self.assertEqual(force_bytes(inst.publisher), force_bytes("FHIR Project team"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.url), force_bytes("http://hl7.org/fhir/ValueSet/example-expansion"))
        self.assertEqual(force_bytes(inst.version), force_bytes("20150622"))
    
    def testValueSet2(self):
        inst = self.instantiate_from("valueset-example-yesnodontknow.json")
        self.assertIsNotNone(inst, "Must have instantiated a ValueSet instance")
        self.implValueSet2(inst)
        
        js = inst.as_json()
        self.assertEqual("ValueSet", js["resourceType"])
        inst2 = valueset.ValueSet(js)
        self.implValueSet2(inst2)
    
    def implValueSet2(self, inst):
        self.assertEqual(force_bytes(inst.compose.include[0].valueSet[0]), force_bytes("http://hl7.org/fhir/ValueSet/v2-0136"))
        self.assertEqual(force_bytes(inst.compose.include[1].concept[0].code), force_bytes("asked"))
        self.assertEqual(force_bytes(inst.compose.include[1].concept[0].display), force_bytes("Don't know"))
        self.assertEqual(force_bytes(inst.compose.include[1].system), force_bytes("http://hl7.org/fhir/data-absent-reason"))
        self.assertEqual(force_bytes(inst.description), force_bytes("For Capturing simple yes-no-don't know answers"))
        self.assertEqual(force_bytes(inst.expansion.contains[0].code), force_bytes("Y"))
        self.assertEqual(force_bytes(inst.expansion.contains[0].display), force_bytes("Yes"))
        self.assertEqual(force_bytes(inst.expansion.contains[0].system), force_bytes("http://hl7.org/fhir/v2/0136"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].code), force_bytes("N"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].display), force_bytes("No"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].system), force_bytes("http://hl7.org/fhir/v2/0136"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].code), force_bytes("asked"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].display), force_bytes("Don't know"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].system), force_bytes("http://hl7.org/fhir/data-absent-reason"))
        self.assertEqual(force_bytes(inst.expansion.identifier), force_bytes("urn:uuid:bf99fe50-2c2b-41ad-bd63-bee6919810b4"))
        self.assertEqual(inst.expansion.timestamp.date, FHIRDate("2015-07-14T10:00:00Z").date)
        self.assertEqual(inst.expansion.timestamp.as_json(), "2015-07-14T10:00:00Z")
        self.assertEqual(force_bytes(inst.id), force_bytes("yesnodontknow"))
        self.assertEqual(force_bytes(inst.name), force_bytes("Yes/No/Don't Know"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.url), force_bytes("http://hl7.org/fhir/ValueSet/yesnodontknow"))
    
    def testValueSet3(self):
        inst = self.instantiate_from("valueset-example-intensional.json")
        self.assertIsNotNone(inst, "Must have instantiated a ValueSet instance")
        self.implValueSet3(inst)
        
        js = inst.as_json()
        self.assertEqual("ValueSet", js["resourceType"])
        inst2 = valueset.ValueSet(js)
        self.implValueSet3(inst2)
    
    def implValueSet3(self, inst):
        self.assertEqual(force_bytes(inst.compose.exclude[0].concept[0].code), force_bytes("5932-9"))
        self.assertEqual(force_bytes(inst.compose.exclude[0].concept[0].display), force_bytes("Cholesterol [Presence] in Blood by Test strip"))
        self.assertEqual(force_bytes(inst.compose.exclude[0].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.compose.include[0].filter[0].op), force_bytes("="))
        self.assertEqual(force_bytes(inst.compose.include[0].filter[0].property), force_bytes("parent"))
        self.assertEqual(force_bytes(inst.compose.include[0].filter[0].value), force_bytes("LP43571-6"))
        self.assertEqual(force_bytes(inst.compose.include[0].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.contact[0].name), force_bytes("FHIR project team"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].system), force_bytes("url"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].value), force_bytes("http://hl7.org/fhir"))
        self.assertEqual(force_bytes(inst.copyright), force_bytes("This content from LOINCÂ® is copyright Â© 1995 Regenstrief Institute, Inc. and the LOINC Committee, and available at no cost under the license at http://loinc.org/terms-of-use"))
        self.assertEqual(inst.date.date, FHIRDate("2015-06-22").date)
        self.assertEqual(inst.date.as_json(), "2015-06-22")
        self.assertEqual(force_bytes(inst.description), force_bytes("This is an example value set that includes all the LOINC codes for serum/plasma cholesterol from v2.36."))
        self.assertTrue(inst.experimental)
        self.assertEqual(force_bytes(inst.id), force_bytes("example-intensional"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://acme.com/identifiers/valuesets"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("loinc-cholesterol-ext"))
        self.assertEqual(force_bytes(inst.meta.profile[0]), force_bytes("http://hl7.org/fhir/StructureDefinition/shareablevalueset"))
        self.assertEqual(force_bytes(inst.name), force_bytes("LOINC Codes for Cholesterol in Serum/Plasma"))
        self.assertEqual(force_bytes(inst.publisher), force_bytes("HL7 International"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.url), force_bytes("http://hl7.org/fhir/ValueSet/example-intensional"))
        self.assertEqual(force_bytes(inst.version), force_bytes("20150622"))
    
    def testValueSet4(self):
        inst = self.instantiate_from("valueset-list-example-codes.json")
        self.assertIsNotNone(inst, "Must have instantiated a ValueSet instance")
        self.implValueSet4(inst)
        
        js = inst.as_json()
        self.assertEqual("ValueSet", js["resourceType"])
        inst2 = valueset.ValueSet(js)
        self.implValueSet4(inst2)
    
    def implValueSet4(self, inst):
        self.assertEqual(force_bytes(inst.compose.include[0].system), force_bytes("http://hl7.org/fhir/list-example-use-codes"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].system), force_bytes("url"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].value), force_bytes("http://hl7.org/fhir"))
        self.assertEqual(inst.date.date, FHIRDate("2017-04-19T07:44:43+10:00").date)
        self.assertEqual(inst.date.as_json(), "2017-04-19T07:44:43+10:00")
        self.assertEqual(force_bytes(inst.description), force_bytes("Example use codes for the List resource - typical kinds of use."))
        self.assertTrue(inst.experimental)
        self.assertEqual(force_bytes(inst.extension[0].url), force_bytes("http://hl7.org/fhir/StructureDefinition/structuredefinition-ballot-status"))
        self.assertEqual(force_bytes(inst.extension[0].valueString), force_bytes("Informative"))
        self.assertEqual(force_bytes(inst.extension[1].url), force_bytes("http://hl7.org/fhir/StructureDefinition/structuredefinition-fmm"))
        self.assertEqual(inst.extension[1].valueInteger, 1)
        self.assertEqual(force_bytes(inst.extension[2].url), force_bytes("http://hl7.org/fhir/StructureDefinition/structuredefinition-wg"))
        self.assertEqual(force_bytes(inst.extension[2].valueCode), force_bytes("fhir"))
        self.assertEqual(force_bytes(inst.id), force_bytes("list-example-codes"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("urn:ietf:rfc:3986"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("urn:oid:2.16.840.1.113883.4.642.3.307"))
        self.assertTrue(inst.immutable)
        self.assertEqual(inst.meta.lastUpdated.date, FHIRDate("2017-04-19T07:44:43.294+10:00").date)
        self.assertEqual(inst.meta.lastUpdated.as_json(), "2017-04-19T07:44:43.294+10:00")
        self.assertEqual(force_bytes(inst.meta.profile[0]), force_bytes("http://hl7.org/fhir/StructureDefinition/shareablevalueset"))
        self.assertEqual(force_bytes(inst.name), force_bytes("Example Use Codes for List"))
        self.assertEqual(force_bytes(inst.publisher), force_bytes("FHIR Project"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.url), force_bytes("http://hl7.org/fhir/ValueSet/list-example-codes"))
        self.assertEqual(force_bytes(inst.version), force_bytes("3.0.1"))
    
    def testValueSet5(self):
        inst = self.instantiate_from("valueset-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a ValueSet instance")
        self.implValueSet5(inst)
        
        js = inst.as_json()
        self.assertEqual("ValueSet", js["resourceType"])
        inst2 = valueset.ValueSet(js)
        self.implValueSet5(inst2)
    
    def implValueSet5(self, inst):
        self.assertTrue(inst.compose.inactive)
        self.assertEqual(force_bytes(inst.compose.include[0].concept[0].code), force_bytes("14647-2"))
        self.assertEqual(force_bytes(inst.compose.include[0].concept[0].display), force_bytes("Cholesterol [Moles/Volume]"))
        self.assertEqual(force_bytes(inst.compose.include[0].concept[1].code), force_bytes("2093-3"))
        self.assertEqual(force_bytes(inst.compose.include[0].concept[1].display), force_bytes("Cholesterol [Mass/Volume]"))
        self.assertEqual(force_bytes(inst.compose.include[0].concept[2].code), force_bytes("35200-5"))
        self.assertEqual(force_bytes(inst.compose.include[0].concept[2].display), force_bytes("Cholesterol [Mass Or Moles/Volume]"))
        self.assertEqual(force_bytes(inst.compose.include[0].concept[3].code), force_bytes("9342-7"))
        self.assertEqual(force_bytes(inst.compose.include[0].concept[3].display), force_bytes("Cholesterol [Percentile]"))
        self.assertEqual(force_bytes(inst.compose.include[0].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.compose.include[0].version), force_bytes("2.36"))
        self.assertEqual(inst.compose.lockedDate.date, FHIRDate("2012-06-13").date)
        self.assertEqual(inst.compose.lockedDate.as_json(), "2012-06-13")
        self.assertEqual(force_bytes(inst.contact[0].name), force_bytes("FHIR project team"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].system), force_bytes("url"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].value), force_bytes("http://hl7.org/fhir"))
        self.assertEqual(force_bytes(inst.copyright), force_bytes("This content from LOINC ® is copyright © 1995 Regenstrief Institute, Inc. and the LOINC Committee, and available at no cost under the license at http://loinc.org/terms-of-use."))
        self.assertEqual(inst.date.date, FHIRDate("2015-06-22").date)
        self.assertEqual(inst.date.as_json(), "2015-06-22")
        self.assertEqual(force_bytes(inst.description), force_bytes("This is an example value set that includes all the LOINC codes for serum/plasma cholesterol from v2.36."))
        self.assertTrue(inst.experimental)
        self.assertEqual(force_bytes(inst.id), force_bytes("example-extensional"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://acme.com/identifiers/valuesets"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("loinc-cholesterol-int"))
        self.assertEqual(force_bytes(inst.meta.profile[0]), force_bytes("http://hl7.org/fhir/StructureDefinition/shareablevalueset"))
        self.assertEqual(force_bytes(inst.name), force_bytes("LOINC Codes for Cholesterol in Serum/Plasma"))
        self.assertEqual(force_bytes(inst.publisher), force_bytes("HL7 International"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.url), force_bytes("http://hl7.org/fhir/ValueSet/example-extensional"))
        self.assertEqual(force_bytes(inst.version), force_bytes("20150622"))
    
    def testValueSet6(self):
        inst = self.instantiate_from("valueset-example-inactive.json")
        self.assertIsNotNone(inst, "Must have instantiated a ValueSet instance")
        self.implValueSet6(inst)
        
        js = inst.as_json()
        self.assertEqual("ValueSet", js["resourceType"])
        inst2 = valueset.ValueSet(js)
        self.implValueSet6(inst2)
    
    def implValueSet6(self, inst):
        self.assertTrue(inst.compose.inactive)
        self.assertEqual(force_bytes(inst.compose.include[0].filter[0].op), force_bytes("descendent-of"))
        self.assertEqual(force_bytes(inst.compose.include[0].filter[0].property), force_bytes("concept"))
        self.assertEqual(force_bytes(inst.compose.include[0].filter[0].value), force_bytes("_ActMoodPredicate"))
        self.assertEqual(force_bytes(inst.compose.include[0].system), force_bytes("http://hl7.org/fhir/v3/ActMood"))
        self.assertEqual(force_bytes(inst.description), force_bytes("HL7 v3 ActMood Prdicate codes, including inactive codes"))
        self.assertEqual(force_bytes(inst.expansion.contains[0].code), force_bytes("CRT"))
        self.assertEqual(force_bytes(inst.expansion.contains[0].display), force_bytes("criterion"))
        self.assertTrue(inst.expansion.contains[0].inactive)
        self.assertEqual(force_bytes(inst.expansion.contains[0].system), force_bytes("http://hl7.org/fhir/v3/ActMood"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].code), force_bytes("EXPEC"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[0].code), force_bytes("GOL"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[0].display), force_bytes("goal"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[0].system), force_bytes("http://hl7.org/fhir/v3/ActMood"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[1].code), force_bytes("RSK"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[1].display), force_bytes("risk"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].contains[1].system), force_bytes("http://hl7.org/fhir/v3/ActMood"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].display), force_bytes("expectation"))
        self.assertEqual(force_bytes(inst.expansion.contains[1].system), force_bytes("http://hl7.org/fhir/v3/ActMood"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].code), force_bytes("OPT"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].display), force_bytes("option"))
        self.assertEqual(force_bytes(inst.expansion.contains[2].system), force_bytes("http://hl7.org/fhir/v3/ActMood"))
        self.assertEqual(force_bytes(inst.expansion.identifier), force_bytes("urn:uuid:46c00b3f-003a-4f31-9d4b-ea2de58b2a99"))
        self.assertEqual(inst.expansion.timestamp.date, FHIRDate("2017-02-26T10:00:00Z").date)
        self.assertEqual(inst.expansion.timestamp.as_json(), "2017-02-26T10:00:00Z")
        self.assertEqual(force_bytes(inst.id), force_bytes("inactive"))
        self.assertEqual(force_bytes(inst.name), force_bytes("Example-inactive"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.title), force_bytes("Example with inactive codes"))
        self.assertEqual(force_bytes(inst.url), force_bytes("http://hl7.org/fhir/ValueSet/inactive"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 (http://hl7.org/fhir/StructureDefinition/ActivityDefinition) on 2019-01-12.
#  2019, SMART Health IT.


from . import domainresource

class ActivityDefinition(domainresource.DomainResource):
    """ The definition of a specific activity to be taken, independent of any
    particular patient or context.
    
    This resource allows for the definition of some activity to be performed,
    independent of a particular patient, practitioner, or other performance
    context.
    """
    
    resource_type = "ActivityDefinition"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.approvalDate = None
        """ When the activity definition was approved by publisher.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.bodySite = None
        """ What part of body to perform on.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.code = None
        """ Detail type of activity.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.contact = None
        """ Contact details for the publisher.
        List of `ContactDetail` items (represented as `dict` in JSON). """
        
        self.contributor = None
        """ A content contributor.
        List of `Contributor` items (represented as `dict` in JSON). """
        
        self.copyright = None
        """ Use and/or publishing restrictions.
        Type `str`. """
        
        self.date = None
        """ Date this was last changed.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.description = None
        """ Natural language description of the activity definition.
        Type `str`. """
        
        self.dosage = None
        """ Detailed dosage instructions.
        List of `Dosage` items (represented as `dict` in JSON). """
        
        self.dynamicValue = None
        """ Dynamic aspects of the definition.
        List of `ActivityDefinitionDynamicValue` items (represented as `dict` in JSON). """
        
        self.effectivePeriod = None
        """ When the activity definition is expected to be used.
        Type `Period` (represented as `dict` in JSON). """
        
        self.experimental = None
        """ For testing purposes, not real usage.
        Type `bool`. """
        
        self.identifier = None
        """ Additional identifier for the activity definition.
        List of `Identifier` items (represented as `dict` in JSON). """
        
        self.jurisdiction = None
        """ Intended jurisdiction for activity definition (if applicable).
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.kind = None
        """ Kind of resource.
        Type `str`. """
        
        self.lastReviewDate = None
        """ When the activity definition was last reviewed.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.library = None
        """ Logic used by the asset.
        List of `FHIRReference` items referencing `Library` (represented as `dict` in JSON). """
        
        self.location = None
        """ Where it should happen.
        Type `FHIRReference` referencing `Location` (represented as `dict` in JSON). """
        
        self.name = None
        """ Name for this activity definition (computer friendly).
        Type `str`. """
        
        self.participant = None
        """ Who should participate in the action.
        List of `ActivityDefinitionParticipant` items (represented as `dict` in JSON). """
        
        self.productCodeableConcept = None
        """ What's administered/supplied.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.productReference = None
        """ What's administered/supplied.
        Type `FHIRReference` referencing `Medication, Substance` (represented as `dict` in JSON). """
        
        self.publisher = None
        """ Name of the publisher (organization or individual).
        Type `str`. """
        
        self.purpose = None
        """ Why this activity definition is defined.
        Type `str`. """
        
        self.quantity = None
        """ How much is administered/consumed/supplied.
        Type `Quantity` (represented as `dict` in JSON). """
        
        self.relatedArtifact = None
        """ Additional documentation, citations, etc.
        List of `RelatedArtifact` items (represented as `dict` in JSON). """
        
        self.status = None
        """ draft | active | retired | unknown.
        Type `str`. """
        
        self.timingDateTime = None
        """ When activity is to occur.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.timingPeriod = None
        """ When activity is to occur.
        Type `Period` (represented as `dict` in JSON). """
        
        self.timingRange = None
        """ When activity is to occur.
        Type `Range` (represented as `dict` in JSON). """
        
        self.timingTiming = None
        """ When activity is to occur.
        Type `Timing` (represented as `dict` in JSON). """
        
        self.title = None
        """ Name for this activity definition (human friendly).
        Type `str`. """
        
        self.topic = None
        """ E.g. Education, Treatment, Assessment, etc.
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.transform = None
        """ Transform to apply the template.
        Type `FHIRReference` referencing `StructureMap` (represented as `dict` in JSON). """
        
        self.url = None
        """ Logical URI to reference this activity definition (globally unique).
        Type `str`. """
        
        self.usage = None
        """ Describes the clinical usage of the asset.
        Type `str`. """
        
        self.useContext = None
        """ Context the content is intended to support.
        List of `UsageContext` items (represented as `dict` in JSON). """
        
        self.version = None
        """ Business version of the activity definition.
        Type `str`. """
        
        super(ActivityDefinition, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(ActivityDefinition, self).elementProperties()
        js.extend([
            ("approvalDate", "approvalDate", fhirdate.FHIRDate, False, None, False),
            ("bodySite", "bodySite", codeableconcept.CodeableConcept, True, None, False),
            ("code", "code", codeableconcept.CodeableConcept, False, None, False),
            ("contact", "contact", contactdetail.ContactDetail, True, None, False),
            ("contributor", "contributor", contributor.Contributor, True, None, False),
            ("copyright", "copyright", str, False, None, False),
            ("date", "date", fhirdate.FHIRDate, False, None, False),
            ("description", "description", str, False, None, False),
            ("dosage", "dosage", dosage.Dosage, True, None, False),
            ("dynamicValue", "dynamicValue", ActivityDefinitionDynamicValue, True, None, False),
            ("effectivePeriod", "effectivePeriod", period.Period, False, None, False),
            ("experimental", "experimental", bool, False, None, False),
            ("identifier", "identifier", identifier.Identifier, True, None, False),
            ("jurisdiction", "jurisdiction", codeableconcept.CodeableConcept, True, None, False),
            ("kind", "kind", str, False, None, False),
            ("lastReviewDate", "lastReviewDate", fhirdate.FHIRDate, False, None, False),
            ("library", "library", fhirreference.FHIRReference, True, None, False),
            ("location", "location", fhirreference.FHIRReference, False, None, False),
            ("name", "name", str, False, None, False),
            ("participant", "participant", ActivityDefinitionParticipant, True, None, False),
            ("productCodeableConcept", "productCodeableConcept", codeableconcept.CodeableConcept, False, "product", False),
            ("productReference", "productReference", fhirreference.FHIRReference, False, "product", False),
            ("publisher", "publisher", str, False, None, False),
            ("purpose", "purpose", str, False, None, False),
            ("quantity", "quantity", quantity.Quantity, False, None, False),
            ("relatedArtifact", "relatedArtifact", relatedartifact.RelatedArtifact, True, None, False),
            ("status", "status", str, False, None, True),
            ("timingDateTime", "timingDateTime", fhirdate.FHIRDate, False, "timing", False),
            ("timingPeriod", "timingPeriod", period.Period, False, "timing", False),
            ("timingRange", "timingRange", range.Range, False, "timing", False),
            ("timingTiming", "timingTiming", timing.Timing, False, "timing", False),
            ("title", "title", str, False, None, False),
            ("topic", "topic", codeableconcept.CodeableConcept, True, None, False),
            ("transform", "transform", fhirreference.FHIRReference, False, None, False),
            ("url", "url", str, False, None, False),
            ("usage", "usage", str, False, None, False),
            ("useContext", "useContext", usagecontext.UsageContext, True, None, False),
            ("version", "version", str, False, None, False),
        ])
        return js


from . import backboneelement

class ActivityDefinitionDynamicValue(backboneelement.BackboneElement):
    """ Dynamic aspects of the definition.
    
    Dynamic values that will be evaluated to produce values for elements of the
    resulting resource. For example, if the dosage of a medication must be
    computed based on the patient's weight, a dynamic value would be used to
    specify an expression that calculated the weight, and the path on the
    intent resource that would contain the result.
    """
    
    resource_type = "ActivityDefinitionDynamicValue"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.description = None
        """ Natural language description of the dynamic value.
        Type `str`. """
        
        self.expression = None
        """ An expression that provides the dynamic value for the customization.
        Type `str`. """
        
        self.language = None
        """ Language of the expression.
        Type `str`. """
        
        self.path = None
        """ The path to the element to be set dynamically.
        Type `str`. """
        
        super(ActivityDefinitionDynamicValue, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(ActivityDefinitionDynamicValue, self).elementProperties()
        js.extend([
            ("description", "description", str, False, None, False),
            ("expression", "expression", str, False, None, False),
            ("language", "language", str, False, None, False),
            ("path", "path", str, False, None, False),
        ])
        return js


class ActivityDefinitionParticipant(backboneelement.BackboneElement):
    """ Who should participate in the action.
    
    Indicates who should participate in performing the action described.
    """
    
    resource_type = "ActivityDefinitionParticipant"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.role = None
        """ E.g. Nurse, Surgeon, Parent, etc.
        Type `CodeableConcept` (represented as `dict` in JSON). """
        
        self.type = None
        """ patient | practitioner | related-person.
        Type `str`. """
        
        super(ActivityDefinitionParticipant, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(ActivityDefinitionParticipant, self).elementProperties()
        js.extend([
            ("role", "role", codeableconcept.CodeableConcept, False, None, False),
            ("type", "type", str, False, None, True),
        ])
        return js


import sys
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import contactdetail
except ImportError:
    contactdetail = sys.modules[__package__ + '.contactdetail']
try:
    from . import contributor
except ImportError:
    contributor = sys.modules[__package__ + '.contributor']
try:
    from . import dosage
except ImportError:
    dosage = sys.modules[__package__ + '.dosage']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']
try:
    from . import period
except ImportError:
    period = sys.modules[__package__ + '.period']
try:
    from . import quantity
except ImportError:
    quantity = sys.modules[__package__ + '.quantity']
try:
    from . import range
except ImportError:
    range = sys.modules[__package__ + '.range']
try:
    from . import relatedartifact
except ImportError:
    relatedartifact = sys.modules[__package__ + '.relatedartifact']
try:
    from . import timing
except ImportError:
    timing = sys.modules[__package__ + '.timing']
try:
    from . import usagecontext
except ImportError:
    usagecontext = sys.modules[__package__ + '.usagecontext']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import procedurerequest
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class ProcedureRequestTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("ProcedureRequest", js["resourceType"])
        return procedurerequest.ProcedureRequest(js)
    
    def testProcedureRequest1(self):
        inst = self.instantiate_from("procedurerequest-example-ft4.json")
        self.assertIsNotNone(inst, "Must have instantiated a ProcedureRequest instance")
        self.implProcedureRequest1(inst)
        
        js = inst.as_json()
        self.assertEqual("ProcedureRequest", js["resourceType"])
        inst2 = procedurerequest.ProcedureRequest(js)
        self.implProcedureRequest1(inst2)
    
    def implProcedureRequest1(self, inst):
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("3024-7"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Free T4"))
        self.assertEqual(force_bytes(inst.id), force_bytes("ft4"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("reflex-order"))
        self.assertEqual(inst.occurrenceDateTime.date, FHIRDate("2015-08-27T09:33:27+07:00").date)
        self.assertEqual(inst.occurrenceDateTime.as_json(), "2015-08-27T09:33:27+07:00")
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedureRequest2(self):
        inst = self.instantiate_from("procedurerequest-example-edu.json")
        self.assertIsNotNone(inst, "Must have instantiated a ProcedureRequest instance")
        self.implProcedureRequest2(inst)
        
        js = inst.as_json()
        self.assertEqual("ProcedureRequest", js["resourceType"])
        inst2 = procedurerequest.ProcedureRequest(js)
        self.implProcedureRequest2(inst2)
    
    def implProcedureRequest2(self, inst):
        self.assertEqual(inst.authoredOn.date, FHIRDate("2016-08-16").date)
        self.assertEqual(inst.authoredOn.as_json(), "2016-08-16")
        self.assertEqual(force_bytes(inst.category[0].coding[0].code), force_bytes("311401005"))
        self.assertEqual(force_bytes(inst.category[0].coding[0].display), force_bytes("Patient education (procedure)"))
        self.assertEqual(force_bytes(inst.category[0].coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.category[0].text), force_bytes("Education"))
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("48023004"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Breast self-examination technique education (procedure)"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Health education - breast examination"))
        self.assertEqual(force_bytes(inst.id), force_bytes("education"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("order"))
        self.assertEqual(inst.occurrenceDateTime.date, FHIRDate("2014-08-16").date)
        self.assertEqual(inst.occurrenceDateTime.as_json(), "2014-08-16")
        self.assertEqual(force_bytes(inst.reasonCode[0].text), force_bytes("early detection of breast mass"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedureRequest3(self):
        inst = self.instantiate_from("procedurerequest-genetics-example-1.json")
        self.assertIsNotNone(inst, "Must have instantiated a ProcedureRequest instance")
        self.implProcedureRequest3(inst)
        
        js = inst.as_json()
        self.assertEqual("ProcedureRequest", js["resourceType"])
        inst2 = procedurerequest.ProcedureRequest(js)
        self.implProcedureRequest3(inst2)
    
    def implProcedureRequest3(self, inst):
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("49874-1"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("ABCB4 gene mutation analysis"))
        self.assertEqual(force_bytes(inst.id), force_bytes("og-example1"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("original-order"))
        self.assertEqual(inst.occurrenceDateTime.date, FHIRDate("2014-05-12T16:16:00-07:00").date)
        self.assertEqual(inst.occurrenceDateTime.as_json(), "2014-05-12T16:16:00-07:00")
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedureRequest4(self):
        inst = self.instantiate_from("procedurerequest-example-lipid.json")
        self.assertIsNotNone(inst, "Must have instantiated a ProcedureRequest instance")
        self.implProcedureRequest4(inst)
        
        js = inst.as_json()
        self.assertEqual("ProcedureRequest", js["resourceType"])
        inst2 = procedurerequest.ProcedureRequest(js)
        self.implProcedureRequest4(inst2)
    
    def implProcedureRequest4(self, inst):
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("LIPID"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://acme.org/tests"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Lipid Panel"))
        self.assertEqual(force_bytes(inst.contained[0].id), force_bytes("fasting"))
        self.assertEqual(force_bytes(inst.contained[1].id), force_bytes("serum"))
        self.assertEqual(force_bytes(inst.id), force_bytes("lipid"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("urn:oid:1.3.4.5.6.7"))
        self.assertEqual(force_bytes(inst.identifier[0].type.coding[0].code), force_bytes("PLAC"))
        self.assertEqual(force_bytes(inst.identifier[0].type.coding[0].system), force_bytes("http://hl7.org/fhir/identifier-type"))
        self.assertEqual(force_bytes(inst.identifier[0].type.text), force_bytes("Placer"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("2345234234234"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("original-order"))
        self.assertEqual(force_bytes(inst.note[0].text), force_bytes("patient is afraid of needles"))
        self.assertEqual(inst.occurrenceDateTime.date, FHIRDate("2013-05-02T16:16:00-07:00").date)
        self.assertEqual(inst.occurrenceDateTime.as_json(), "2013-05-02T16:16:00-07:00")
        self.assertEqual(force_bytes(inst.reasonCode[0].coding[0].code), force_bytes("V173"))
        self.assertEqual(force_bytes(inst.reasonCode[0].coding[0].display), force_bytes("Fam hx-ischem heart dis"))
        self.assertEqual(force_bytes(inst.reasonCode[0].coding[0].system), force_bytes("http://hl7.org/fhir/sid/icd-9"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedureRequest5(self):
        inst = self.instantiate_from("procedurerequest-example-pgx.json")
        self.assertIsNotNone(inst, "Must have instantiated a ProcedureRequest instance")
        self.implProcedureRequest5(inst)
        
        js = inst.as_json()
        self.assertEqual("ProcedureRequest", js["resourceType"])
        inst2 = procedurerequest.ProcedureRequest(js)
        self.implProcedureRequest5(inst2)
    
    def implProcedureRequest5(self, inst):
        self.assertEqual(inst.authoredOn.date, FHIRDate("2016-10-10T15:00:00-07:00").date)
        self.assertEqual(inst.authoredOn.as_json(), "2016-10-10T15:00:00-07:00")
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("47403-1"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("CYP2D6 gene targeted mutation analysis"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.id), force_bytes("example-pgx"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("original-order"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedureRequest6(self):
        inst = self.instantiate_from("procedurerequest-example-di.json")
        self.assertIsNotNone(inst, "Must have instantiated a ProcedureRequest instance")
        self.implProcedureRequest6(inst)
        
        js = inst.as_json()
        self.assertEqual("ProcedureRequest", js["resourceType"])
        inst2 = procedurerequest.ProcedureRequest(js)
        self.implProcedureRequest6(inst2)
    
    def implProcedureRequest6(self, inst):
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("24627-2"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://loinc.org"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Chest CT"))
        self.assertEqual(force_bytes(inst.id), force_bytes("di"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("original-order"))
        self.assertEqual(inst.occurrenceDateTime.date, FHIRDate("2013-05-08T09:33:27+07:00").date)
        self.assertEqual(inst.occurrenceDateTime.as_json(), "2013-05-08T09:33:27+07:00")
        self.assertEqual(force_bytes(inst.reasonCode[0].text), force_bytes("Check for metastatic disease"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedureRequest7(self):
        inst = self.instantiate_from("procedurerequest-example-pt.json")
        self.assertIsNotNone(inst, "Must have instantiated a ProcedureRequest instance")
        self.implProcedureRequest7(inst)
        
        js = inst.as_json()
        self.assertEqual("ProcedureRequest", js["resourceType"])
        inst2 = procedurerequest.ProcedureRequest(js)
        self.implProcedureRequest7(inst2)
    
    def implProcedureRequest7(self, inst):
        self.assertEqual(inst.authoredOn.date, FHIRDate("2016-09-20").date)
        self.assertEqual(inst.authoredOn.as_json(), "2016-09-20")
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].code), force_bytes("36701003"))
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].display), force_bytes("Both knees (body structure)"))
        self.assertEqual(force_bytes(inst.bodySite[0].coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.bodySite[0].text), force_bytes("Both knees"))
        self.assertEqual(force_bytes(inst.category[0].coding[0].code), force_bytes("386053000"))
        self.assertEqual(force_bytes(inst.category[0].coding[0].display), force_bytes("Evaluation procedure (procedure)"))
        self.assertEqual(force_bytes(inst.category[0].coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.category[0].text), force_bytes("Evaluation"))
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("710830005"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Assessment of passive range of motion (procedure)"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Assessment of passive range of motion"))
        self.assertEqual(force_bytes(inst.id), force_bytes("physical-therapy"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("order"))
        self.assertEqual(inst.occurrenceDateTime.date, FHIRDate("2016-09-27").date)
        self.assertEqual(inst.occurrenceDateTime.as_json(), "2016-09-27")
        self.assertEqual(force_bytes(inst.reasonCode[0].text), force_bytes("assessment of mobility limitations due to osteoarthritis"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedureRequest8(self):
        inst = self.instantiate_from("procedurerequest-example-colonoscopy.json")
        self.assertIsNotNone(inst, "Must have instantiated a ProcedureRequest instance")
        self.implProcedureRequest8(inst)
        
        js = inst.as_json()
        self.assertEqual("ProcedureRequest", js["resourceType"])
        inst2 = procedurerequest.ProcedureRequest(js)
        self.implProcedureRequest8(inst2)
    
    def implProcedureRequest8(self, inst):
        self.assertEqual(inst.authoredOn.date, FHIRDate("2017-03-05").date)
        self.assertEqual(inst.authoredOn.as_json(), "2017-03-05")
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("73761001"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Colonoscopy (procedure)"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Colonoscopy"))
        self.assertEqual(force_bytes(inst.id), force_bytes("colonoscopy"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("45678"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("order"))
        self.assertEqual(force_bytes(inst.requisition.system), force_bytes("http://bumc.org/requisitions"))
        self.assertEqual(force_bytes(inst.requisition.value), force_bytes("req12345"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedureRequest9(self):
        inst = self.instantiate_from("procedurerequest-example-implant.json")
        self.assertIsNotNone(inst, "Must have instantiated a ProcedureRequest instance")
        self.implProcedureRequest9(inst)
        
        js = inst.as_json()
        self.assertEqual("ProcedureRequest", js["resourceType"])
        inst2 = procedurerequest.ProcedureRequest(js)
        self.implProcedureRequest9(inst2)
    
    def implProcedureRequest9(self, inst):
        self.assertEqual(inst.authoredOn.date, FHIRDate("2015-03-30").date)
        self.assertEqual(inst.authoredOn.as_json(), "2015-03-30")
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("25267002"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Insertion of intracardiac pacemaker (procedure)"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Implant Pacemaker"))
        self.assertEqual(force_bytes(inst.id), force_bytes("example-implant"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("order"))
        self.assertEqual(force_bytes(inst.reasonCode[0].text), force_bytes("Bradycardia"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testProcedureRequest10(self):
        inst = self.instantiate_from("procedurerequest-example4.json")
        self.assertIsNotNone(inst, "Must have instantiated a ProcedureRequest instance")
        self.implProcedureRequest10(inst)
        
        js = inst.as_json()
        self.assertEqual("ProcedureRequest", js["resourceType"])
        inst2 = procedurerequest.ProcedureRequest(js)
        self.implProcedureRequest10(inst2)
    
    def implProcedureRequest10(self, inst):
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("229115003"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Bench Press (regime/therapy) "))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.id), force_bytes("benchpress"))
        self.assertEqual(force_bytes(inst.intent), force_bytes("plan"))
        self.assertEqual(force_bytes(inst.note[0].text), force_bytes("Start with 30kg and increase in increments of 5kg when you feel ready"))
        self.assertEqual(inst.occurrenceTiming.repeat.count, 20)
        self.assertEqual(inst.occurrenceTiming.repeat.countMax, 30)
        self.assertEqual(inst.occurrenceTiming.repeat.frequency, 3)
        self.assertEqual(inst.occurrenceTiming.repeat.period, 1)
        self.assertEqual(force_bytes(inst.occurrenceTiming.repeat.periodUnit), force_bytes("wk"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 (http://hl7.org/fhir/StructureDefinition/ProcessRequest) on 2019-01-12.
#  2019, SMART Health IT.


from . import domainresource

class ProcessRequest(domainresource.DomainResource):
    """ Request to perform some action on or in regards to an existing resource.
    
    This resource provides the target, request and response, and action details
    for an action to be performed by the target on or about existing resources.
    """
    
    resource_type = "ProcessRequest"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.action = None
        """ cancel | poll | reprocess | status.
        Type `str`. """
        
        self.created = None
        """ Creation date.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.exclude = None
        """ Resource type(s) to exclude.
        List of `str` items. """
        
        self.identifier = None
        """ Business Identifier.
        List of `Identifier` items (represented as `dict` in JSON). """
        
        self.include = None
        """ Resource type(s) to include.
        List of `str` items. """
        
        self.item = None
        """ Items to re-adjudicate.
        List of `ProcessRequestItem` items (represented as `dict` in JSON). """
        
        self.nullify = None
        """ Remove history.
        Type `bool`. """
        
        self.organization = None
        """ Responsible organization.
        Type `FHIRReference` referencing `Organization` (represented as `dict` in JSON). """
        
        self.period = None
        """ Selection period.
        Type `Period` (represented as `dict` in JSON). """
        
        self.provider = None
        """ Responsible practitioner.
        Type `FHIRReference` referencing `Practitioner` (represented as `dict` in JSON). """
        
        self.reference = None
        """ Reference number/string.
        Type `str`. """
        
        self.request = None
        """ Reference to the Request resource.
        Type `FHIRReference` referencing `Resource` (represented as `dict` in JSON). """
        
        self.response = None
        """ Reference to the Response resource.
        Type `FHIRReference` referencing `Resource` (represented as `dict` in JSON). """
        
        self.status = None
        """ active | cancelled | draft | entered-in-error.
        Type `str`. """
        
        self.target = None
        """ Party which is the target of the request.
        Type `FHIRReference` referencing `Organization` (represented as `dict` in JSON). """
        
        super(ProcessRequest, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(ProcessRequest, self).elementProperties()
        js.extend([
            ("action", "action", str, False, None, False),
            ("created", "created", fhirdate.FHIRDate, False, None, False),
            ("exclude", "exclude", str, True, None, False),
            ("identifier", "identifier", identifier.Identifier, True, None, False),
            ("include", "include", str, True, None, False),
            ("item", "item", ProcessRequestItem, True, None, False),
            ("nullify", "nullify", bool, False, None, False),
            ("organization", "organization", fhirreference.FHIRReference, False, None, False),
            ("period", "period", period.Period, False, None, False),
            ("provider", "provider", fhirreference.FHIRReference, False, None, False),
            ("reference", "reference", str, False, None, False),
            ("request", "request", fhirreference.FHIRReference, False, None, False),
            ("response", "response", fhirreference.FHIRReference, False, None, False),
            ("status", "status", str, False, None, False),
            ("target", "target", fhirreference.FHIRReference, False, None, False),
        ])
        return js


from . import backboneelement

class ProcessRequestItem(backboneelement.BackboneElement):
    """ Items to re-adjudicate.
    
    List of top level items to be re-adjudicated, if none specified then the
    entire submission is re-adjudicated.
    """
    
    resource_type = "ProcessRequestItem"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.sequenceLinkId = None
        """ Service instance.
        Type `int`. """
        
        super(ProcessRequestItem, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(ProcessRequestItem, self).elementProperties()
        js.extend([
            ("sequenceLinkId", "sequenceLinkId", int, False, None, True),
        ])
        return js


import sys
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']
try:
    from . import period
except ImportError:
    period = sys.modules[__package__ + '.period']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 (http://hl7.org/fhir/StructureDefinition/ImagingManifest) on 2019-01-12.
#  2019, SMART Health IT.


from . import domainresource

class ImagingManifest(domainresource.DomainResource):
    """ Key Object Selection.
    
    A text description of the DICOM SOP instances selected in the
    ImagingManifest; or the reason for, or significance of, the selection.
    """
    
    resource_type = "ImagingManifest"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.author = None
        """ Author (human or machine).
        Type `FHIRReference` referencing `Practitioner, Device, Organization, Patient, RelatedPerson` (represented as `dict` in JSON). """
        
        self.authoringTime = None
        """ Time when the selection of instances was made.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.description = None
        """ Description text.
        Type `str`. """
        
        self.identifier = None
        """ SOP Instance UID.
        Type `Identifier` (represented as `dict` in JSON). """
        
        self.patient = None
        """ Patient of the selected objects.
        Type `FHIRReference` referencing `Patient` (represented as `dict` in JSON). """
        
        self.study = None
        """ Study identity of the selected instances.
        List of `ImagingManifestStudy` items (represented as `dict` in JSON). """
        
        super(ImagingManifest, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(ImagingManifest, self).elementProperties()
        js.extend([
            ("author", "author", fhirreference.FHIRReference, False, None, False),
            ("authoringTime", "authoringTime", fhirdate.FHIRDate, False, None, False),
            ("description", "description", str, False, None, False),
            ("identifier", "identifier", identifier.Identifier, False, None, False),
            ("patient", "patient", fhirreference.FHIRReference, False, None, True),
            ("study", "study", ImagingManifestStudy, True, None, True),
        ])
        return js


from . import backboneelement

class ImagingManifestStudy(backboneelement.BackboneElement):
    """ Study identity of the selected instances.
    
    Study identity and locating information of the DICOM SOP instances in the
    selection.
    """
    
    resource_type = "ImagingManifestStudy"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.endpoint = None
        """ Study access service endpoint.
        List of `FHIRReference` items referencing `Endpoint` (represented as `dict` in JSON). """
        
        self.imagingStudy = None
        """ Reference to ImagingStudy.
        Type `FHIRReference` referencing `ImagingStudy` (represented as `dict` in JSON). """
        
        self.series = None
        """ Series identity of the selected instances.
        List of `ImagingManifestStudySeries` items (represented as `dict` in JSON). """
        
        self.uid = None
        """ Study instance UID.
        Type `str`. """
        
        super(ImagingManifestStudy, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(ImagingManifestStudy, self).elementProperties()
        js.extend([
            ("endpoint", "endpoint", fhirreference.FHIRReference, True, None, False),
            ("imagingStudy", "imagingStudy", fhirreference.FHIRReference, False, None, False),
            ("series", "series", ImagingManifestStudySeries, True, None, True),
            ("uid", "uid", str, False, None, True),
        ])
        return js


class ImagingManifestStudySeries(backboneelement.BackboneElement):
    """ Series identity of the selected instances.
    
    Series identity and locating information of the DICOM SOP instances in the
    selection.
    """
    
    resource_type = "ImagingManifestStudySeries"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.endpoint = None
        """ Series access endpoint.
        List of `FHIRReference` items referencing `Endpoint` (represented as `dict` in JSON). """
        
        self.instance = None
        """ The selected instance.
        List of `ImagingManifestStudySeriesInstance` items (represented as `dict` in JSON). """
        
        self.uid = None
        """ Series instance UID.
        Type `str`. """
        
        super(ImagingManifestStudySeries, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(ImagingManifestStudySeries, self).elementProperties()
        js.extend([
            ("endpoint", "endpoint", fhirreference.FHIRReference, True, None, False),
            ("instance", "instance", ImagingManifestStudySeriesInstance, True, None, True),
            ("uid", "uid", str, False, None, True),
        ])
        return js


class ImagingManifestStudySeriesInstance(backboneelement.BackboneElement):
    """ The selected instance.
    
    Identity and locating information of the selected DICOM SOP instances.
    """
    
    resource_type = "ImagingManifestStudySeriesInstance"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.sopClass = None
        """ SOP class UID of instance.
        Type `str`. """
        
        self.uid = None
        """ Selected instance UID.
        Type `str`. """
        
        super(ImagingManifestStudySeriesInstance, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(ImagingManifestStudySeriesInstance, self).elementProperties()
        js.extend([
            ("sopClass", "sopClass", str, False, None, True),
            ("uid", "uid", str, False, None, True),
        ])
        return js


import sys
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import familymemberhistory
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class FamilyMemberHistoryTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("FamilyMemberHistory", js["resourceType"])
        return familymemberhistory.FamilyMemberHistory(js)
    
    def testFamilyMemberHistory1(self):
        inst = self.instantiate_from("familymemberhistory-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a FamilyMemberHistory instance")
        self.implFamilyMemberHistory1(inst)
        
        js = inst.as_json()
        self.assertEqual("FamilyMemberHistory", js["resourceType"])
        inst2 = familymemberhistory.FamilyMemberHistory(js)
        self.implFamilyMemberHistory1(inst2)
    
    def implFamilyMemberHistory1(self, inst):
        self.assertEqual(force_bytes(inst.condition[0].code.coding[0].code), force_bytes("315619001"))
        self.assertEqual(force_bytes(inst.condition[0].code.coding[0].display), force_bytes("Myocardial Infarction"))
        self.assertEqual(force_bytes(inst.condition[0].code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.condition[0].code.text), force_bytes("Heart Attack"))
        self.assertEqual(force_bytes(inst.condition[0].note[0].text), force_bytes("Was fishing at the time. At least he went doing someting he loved."))
        self.assertEqual(force_bytes(inst.condition[0].onsetAge.code), force_bytes("a"))
        self.assertEqual(force_bytes(inst.condition[0].onsetAge.system), force_bytes("http://unitsofmeasure.org"))
        self.assertEqual(force_bytes(inst.condition[0].onsetAge.unit), force_bytes("yr"))
        self.assertEqual(inst.condition[0].onsetAge.value, 74)
        self.assertEqual(inst.date.date, FHIRDate("2011-03-18").date)
        self.assertEqual(inst.date.as_json(), "2011-03-18")
        self.assertEqual(force_bytes(inst.gender), force_bytes("male"))
        self.assertEqual(force_bytes(inst.id), force_bytes("father"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("12345"))
        self.assertFalse(inst.notDone)
        self.assertEqual(force_bytes(inst.relationship.coding[0].code), force_bytes("FTH"))
        self.assertEqual(force_bytes(inst.relationship.coding[0].display), force_bytes("father"))
        self.assertEqual(force_bytes(inst.relationship.coding[0].system), force_bytes("http://hl7.org/fhir/v3/RoleCode"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">Father died of a heart attack aged 74</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testFamilyMemberHistory2(self):
        inst = self.instantiate_from("familymemberhistory-example-mother.json")
        self.assertIsNotNone(inst, "Must have instantiated a FamilyMemberHistory instance")
        self.implFamilyMemberHistory2(inst)
        
        js = inst.as_json()
        self.assertEqual("FamilyMemberHistory", js["resourceType"])
        inst2 = familymemberhistory.FamilyMemberHistory(js)
        self.implFamilyMemberHistory2(inst2)
    
    def implFamilyMemberHistory2(self, inst):
        self.assertEqual(force_bytes(inst.condition[0].code.coding[0].code), force_bytes("371041009"))
        self.assertEqual(force_bytes(inst.condition[0].code.coding[0].display), force_bytes("Embolic Stroke"))
        self.assertEqual(force_bytes(inst.condition[0].code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.condition[0].code.text), force_bytes("Stroke"))
        self.assertEqual(force_bytes(inst.condition[0].onsetAge.code), force_bytes("a"))
        self.assertEqual(force_bytes(inst.condition[0].onsetAge.system), force_bytes("http://unitsofmeasure.org"))
        self.assertEqual(force_bytes(inst.condition[0].onsetAge.unit), force_bytes("yr"))
        self.assertEqual(inst.condition[0].onsetAge.value, 56)
        self.assertEqual(force_bytes(inst.id), force_bytes("mother"))
        self.assertEqual(force_bytes(inst.relationship.coding[0].code), force_bytes("MTH"))
        self.assertEqual(force_bytes(inst.relationship.coding[0].display), force_bytes("mother"))
        self.assertEqual(force_bytes(inst.relationship.coding[0].system), force_bytes("http://hl7.org/fhir/v3/RoleCode"))
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">Mother died of a stroke aged 56</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 on 2019-01-12.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json
import six
from fhir.resources import appointment
from fhir.resources.fhirdate import FHIRDate

from .fixtures import force_bytes


@pytest.mark.usefixtures("base_settings")
class AppointmentTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Appointment", js["resourceType"])
        return appointment.Appointment(js)
    
    def testAppointment1(self):
        inst = self.instantiate_from("appointment-example2doctors.json")
        self.assertIsNotNone(inst, "Must have instantiated a Appointment instance")
        self.implAppointment1(inst)
        
        js = inst.as_json()
        self.assertEqual("Appointment", js["resourceType"])
        inst2 = appointment.Appointment(js)
        self.implAppointment1(inst2)
    
    def implAppointment1(self, inst):
        self.assertEqual(force_bytes(inst.appointmentType.coding[0].code), force_bytes("wi"))
        self.assertEqual(force_bytes(inst.appointmentType.coding[0].display), force_bytes("Walk in"))
        self.assertEqual(force_bytes(inst.appointmentType.coding[0].system), force_bytes("http://example.org/appointment-type"))
        self.assertEqual(force_bytes(inst.comment), force_bytes("Clarify the results of the MRI to ensure context of test was correct"))
        self.assertEqual(force_bytes(inst.description), force_bytes("Discussion about Peter Chalmers MRI results"))
        self.assertEqual(inst.end.date, FHIRDate("2013-12-09T11:00:00Z").date)
        self.assertEqual(inst.end.as_json(), "2013-12-09T11:00:00Z")
        self.assertEqual(force_bytes(inst.id), force_bytes("2docs"))
        self.assertEqual(force_bytes(inst.participant[0].required), force_bytes("information-only"))
        self.assertEqual(force_bytes(inst.participant[0].status), force_bytes("accepted"))
        self.assertEqual(force_bytes(inst.participant[1].required), force_bytes("required"))
        self.assertEqual(force_bytes(inst.participant[1].status), force_bytes("accepted"))
        self.assertEqual(force_bytes(inst.participant[2].required), force_bytes("required"))
        self.assertEqual(force_bytes(inst.participant[2].status), force_bytes("accepted"))
        self.assertEqual(force_bytes(inst.participant[3].required), force_bytes("information-only"))
        self.assertEqual(force_bytes(inst.participant[3].status), force_bytes("accepted"))
        self.assertEqual(inst.priority, 5)
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].code), force_bytes("gp"))
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].display), force_bytes("General Practice"))
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].system), force_bytes("http://example.org/service-category"))
        self.assertEqual(force_bytes(inst.serviceType[0].coding[0].code), force_bytes("52"))
        self.assertEqual(force_bytes(inst.serviceType[0].coding[0].display), force_bytes("General Discussion"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].code), force_bytes("gp"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].display), force_bytes("General Practice"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].system), force_bytes("http://example.org/specialty"))
        self.assertEqual(inst.start.date, FHIRDate("2013-12-09T09:00:00Z").date)
        self.assertEqual(inst.start.as_json(), "2013-12-09T09:00:00Z")
        self.assertEqual(force_bytes(inst.status), force_bytes("booked"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">Brian MRI results discussion</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testAppointment2(self):
        inst = self.instantiate_from("appointment-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Appointment instance")
        self.implAppointment2(inst)
        
        js = inst.as_json()
        self.assertEqual("Appointment", js["resourceType"])
        inst2 = appointment.Appointment(js)
        self.implAppointment2(inst2)
    
    def implAppointment2(self, inst):
        self.assertEqual(force_bytes(inst.appointmentType.coding[0].code), force_bytes("follow"))
        self.assertEqual(force_bytes(inst.appointmentType.coding[0].display), force_bytes("Followup"))
        self.assertEqual(force_bytes(inst.appointmentType.coding[0].system), force_bytes("http://example.org/appointment-type"))
        self.assertEqual(force_bytes(inst.comment), force_bytes("Further expand on the results of the MRI and determine the next actions that may be appropriate."))
        self.assertEqual(inst.created.date, FHIRDate("2013-10-10").date)
        self.assertEqual(inst.created.as_json(), "2013-10-10")
        self.assertEqual(force_bytes(inst.description), force_bytes("Discussion on the results of your recent MRI"))
        self.assertEqual(inst.end.date, FHIRDate("2013-12-10T11:00:00Z").date)
        self.assertEqual(inst.end.as_json(), "2013-12-10T11:00:00Z")
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.participant[0].required), force_bytes("required"))
        self.assertEqual(force_bytes(inst.participant[0].status), force_bytes("accepted"))
        self.assertEqual(force_bytes(inst.participant[1].required), force_bytes("required"))
        self.assertEqual(force_bytes(inst.participant[1].status), force_bytes("accepted"))
        self.assertEqual(force_bytes(inst.participant[1].type[0].coding[0].code), force_bytes("ATND"))
        self.assertEqual(force_bytes(inst.participant[1].type[0].coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.participant[2].required), force_bytes("required"))
        self.assertEqual(force_bytes(inst.participant[2].status), force_bytes("accepted"))
        self.assertEqual(inst.priority, 5)
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].code), force_bytes("gp"))
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].display), force_bytes("General Practice"))
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].system), force_bytes("http://example.org/service-category"))
        self.assertEqual(force_bytes(inst.serviceType[0].coding[0].code), force_bytes("52"))
        self.assertEqual(force_bytes(inst.serviceType[0].coding[0].display), force_bytes("General Discussion"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].code), force_bytes("gp"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].display), force_bytes("General Practice"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].system), force_bytes("http://example.org/specialty"))
        self.assertEqual(inst.start.date, FHIRDate("2013-12-10T09:00:00Z").date)
        self.assertEqual(inst.start.as_json(), "2013-12-10T09:00:00Z")
        self.assertEqual(force_bytes(inst.status), force_bytes("booked"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">Brian MRI results discussion</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testAppointment3(self):
        inst = self.instantiate_from("appointment-example-request.json")
        self.assertIsNotNone(inst, "Must have instantiated a Appointment instance")
        self.implAppointment3(inst)
        
        js = inst.as_json()
        self.assertEqual("Appointment", js["resourceType"])
        inst2 = appointment.Appointment(js)
        self.implAppointment3(inst2)
    
    def implAppointment3(self, inst):
        self.assertEqual(force_bytes(inst.appointmentType.coding[0].code), force_bytes("wi"))
        self.assertEqual(force_bytes(inst.appointmentType.coding[0].display), force_bytes("Walk in"))
        self.assertEqual(force_bytes(inst.appointmentType.coding[0].system), force_bytes("http://example.org/appointment-type"))
        self.assertEqual(force_bytes(inst.comment), force_bytes("Further expand on the results of the MRI and determine the next actions that may be appropriate."))
        self.assertEqual(inst.created.date, FHIRDate("2015-12-02").date)
        self.assertEqual(inst.created.as_json(), "2015-12-02")
        self.assertEqual(force_bytes(inst.description), force_bytes("Discussion on the results of your recent MRI"))
        self.assertEqual(force_bytes(inst.id), force_bytes("examplereq"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://example.org/sampleappointment-identifier"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("123"))
        self.assertEqual(inst.minutesDuration, 15)
        self.assertEqual(force_bytes(inst.participant[0].required), force_bytes("required"))
        self.assertEqual(force_bytes(inst.participant[0].status), force_bytes("needs-action"))
        self.assertEqual(force_bytes(inst.participant[1].required), force_bytes("required"))
        self.assertEqual(force_bytes(inst.participant[1].status), force_bytes("needs-action"))
        self.assertEqual(force_bytes(inst.participant[1].type[0].coding[0].code), force_bytes("ATND"))
        self.assertEqual(force_bytes(inst.participant[1].type[0].coding[0].system), force_bytes("http://hl7.org/fhir/v3/ParticipationType"))
        self.assertEqual(force_bytes(inst.participant[2].required), force_bytes("required"))
        self.assertEqual(force_bytes(inst.participant[2].status), force_bytes("accepted"))
        self.assertEqual(inst.priority, 5)
        self.assertEqual(force_bytes(inst.reason[0].coding[0].code), force_bytes("413095006"))
        self.assertEqual(force_bytes(inst.reason[0].coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.reason[0].text), force_bytes("Clinical Review"))
        self.assertEqual(inst.requestedPeriod[0].end.date, FHIRDate("2016-06-09").date)
        self.assertEqual(inst.requestedPeriod[0].end.as_json(), "2016-06-09")
        self.assertEqual(inst.requestedPeriod[0].start.date, FHIRDate("2016-06-02").date)
        self.assertEqual(inst.requestedPeriod[0].start.as_json(), "2016-06-02")
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].code), force_bytes("gp"))
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].display), force_bytes("General Practice"))
        self.assertEqual(force_bytes(inst.serviceCategory.coding[0].system), force_bytes("http://example.org/service-category"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].code), force_bytes("gp"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].display), force_bytes("General Practice"))
        self.assertEqual(force_bytes(inst.specialty[0].coding[0].system), force_bytes("http://example.org/specialty"))
        self.assertEqual(force_bytes(inst.status), force_bytes("proposed"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">Brian MRI results discussion</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 3.0.1.11917 (http://hl7.org/fhir/StructureDefinition/MetadataResource) on 2019-01-12.
#  2019, SMART Health IT.


from . import domainresource

class MetadataResource(domainresource.DomainResource):
    """ Common Ancestor declaration for definitional resources.
    
    Common Ancestor declaration for conformance and knowledge artifact
    resources.
    """
    
    resource_type = "MetadataResource"
    
    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.
        
        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """
        
        self.contact = None
        """ Contact details for the publisher.
        List of `ContactDetail` items (represented as `dict` in JSON). """
        
        self.date = None
        """ Date this was last changed.
        Type `FHIRDate` (represented as `str` in JSON). """
        
        self.description = None
        """ Natural language description of the metadata resource.
        Type `str`. """
        
        self.experimental = None
        """ For testing purposes, not real usage.
        Type `bool`. """
        
        self.jurisdiction = None
        """ Intended jurisdiction for metadata resource (if applicable).
        List of `CodeableConcept` items (represented as `dict` in JSON). """
        
        self.name = None
        """ Name for this metadata resource (computer friendly).
        Type `str`. """
        
        self.publisher = None
        """ Name of the publisher (organization or individual).
        Type `str`. """
        
        self.status = None
        """ draft | active | retired | unknown.
        Type `str`. """
        
        self.title = None
        """ Name for this metadata resource (human friendly).
        Type `str`. """
        
        self.url = None
        """ Logical URI to reference this metadata resource (globally unique).
        Type `str`. """
        
        self.useContext = None
        """ Context the content is intended to support.
        List of `UsageContext` items (represented as `dict` in JSON). """
        
        self.version = None
        """ Business version of the metadata resource.
        Type `str`. """
        
        super(MetadataResource, self).__init__(jsondict=jsondict, strict=strict)
    
    def elementProperties(self):
        js = super(MetadataResource, self).elementProperties()
        js.extend([
            ("contact", "contact", contactdetail.ContactDetail, True, None, False),
            ("date", "date", fhirdate.FHIRDate, False, None, False),
            ("description", "description", str, False, None, False),
            ("experimental", "experimental", bool, False, None, False),
            ("jurisdiction", "jurisdiction", codeableconcept.CodeableConcept, True, None, False),
            ("name", "name", str, False, None, False),
            ("publisher", "publisher", str, False, None, False),
            ("status", "status", str, False, None, True),
            ("title", "title", str, False, None, False),
            ("url", "url", str, False, None, False),
            ("useContext", "useContext", usagecontext.UsageContext, True, None, False),
            ("version", "version", str, False, None, False),
        ])
        return js


import sys
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import contactdetail
except ImportError:
    contactdetail = sys.modules[__package__ + '.contactdetail']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import usagecontext
except ImportError:
    usagecontext = sys.modules[__package__ + '.usagecontext']
